#ifdef NOFLAGS_SUPPORT
/* 68040 */
extern const struct comptbl op_smalltbl_0_nf[];
#endif
extern const struct comptbl op_smalltbl_0_comp_nf[];
extern const struct comptbl op_smalltbl_0_comp_ff[];
extern compop_func op_0_0_comp_ff;
extern compop_func op_10_0_comp_ff;
extern compop_func op_18_0_comp_ff;
extern compop_func op_20_0_comp_ff;
extern compop_func op_28_0_comp_ff;
extern compop_func op_30_0_comp_ff;
extern compop_func op_38_0_comp_ff;
extern compop_func op_39_0_comp_ff;
extern compop_func op_3c_0_comp_ff;
extern compop_func op_40_0_comp_ff;
extern compop_func op_50_0_comp_ff;
extern compop_func op_58_0_comp_ff;
extern compop_func op_60_0_comp_ff;
extern compop_func op_68_0_comp_ff;
extern compop_func op_70_0_comp_ff;
extern compop_func op_78_0_comp_ff;
extern compop_func op_79_0_comp_ff;
extern compop_func op_80_0_comp_ff;
extern compop_func op_90_0_comp_ff;
extern compop_func op_98_0_comp_ff;
extern compop_func op_a0_0_comp_ff;
extern compop_func op_a8_0_comp_ff;
extern compop_func op_b0_0_comp_ff;
extern compop_func op_b8_0_comp_ff;
extern compop_func op_b9_0_comp_ff;
extern compop_func op_100_0_comp_ff;
extern compop_func op_110_0_comp_ff;
extern compop_func op_118_0_comp_ff;
extern compop_func op_120_0_comp_ff;
extern compop_func op_128_0_comp_ff;
extern compop_func op_130_0_comp_ff;
extern compop_func op_138_0_comp_ff;
extern compop_func op_139_0_comp_ff;
extern compop_func op_13a_0_comp_ff;
extern compop_func op_13b_0_comp_ff;
extern compop_func op_13c_0_comp_ff;
extern compop_func op_140_0_comp_ff;
extern compop_func op_150_0_comp_ff;
extern compop_func op_158_0_comp_ff;
extern compop_func op_160_0_comp_ff;
extern compop_func op_168_0_comp_ff;
extern compop_func op_170_0_comp_ff;
extern compop_func op_178_0_comp_ff;
extern compop_func op_179_0_comp_ff;
extern compop_func op_180_0_comp_ff;
extern compop_func op_190_0_comp_ff;
extern compop_func op_198_0_comp_ff;
extern compop_func op_1a0_0_comp_ff;
extern compop_func op_1a8_0_comp_ff;
extern compop_func op_1b0_0_comp_ff;
extern compop_func op_1b8_0_comp_ff;
extern compop_func op_1b9_0_comp_ff;
extern compop_func op_1c0_0_comp_ff;
extern compop_func op_1d0_0_comp_ff;
extern compop_func op_1d8_0_comp_ff;
extern compop_func op_1e0_0_comp_ff;
extern compop_func op_1e8_0_comp_ff;
extern compop_func op_1f0_0_comp_ff;
extern compop_func op_1f8_0_comp_ff;
extern compop_func op_1f9_0_comp_ff;
extern compop_func op_200_0_comp_ff;
extern compop_func op_210_0_comp_ff;
extern compop_func op_218_0_comp_ff;
extern compop_func op_220_0_comp_ff;
extern compop_func op_228_0_comp_ff;
extern compop_func op_230_0_comp_ff;
extern compop_func op_238_0_comp_ff;
extern compop_func op_239_0_comp_ff;
extern compop_func op_23c_0_comp_ff;
extern compop_func op_240_0_comp_ff;
extern compop_func op_250_0_comp_ff;
extern compop_func op_258_0_comp_ff;
extern compop_func op_260_0_comp_ff;
extern compop_func op_268_0_comp_ff;
extern compop_func op_270_0_comp_ff;
extern compop_func op_278_0_comp_ff;
extern compop_func op_279_0_comp_ff;
extern compop_func op_280_0_comp_ff;
extern compop_func op_290_0_comp_ff;
extern compop_func op_298_0_comp_ff;
extern compop_func op_2a0_0_comp_ff;
extern compop_func op_2a8_0_comp_ff;
extern compop_func op_2b0_0_comp_ff;
extern compop_func op_2b8_0_comp_ff;
extern compop_func op_2b9_0_comp_ff;
extern compop_func op_400_0_comp_ff;
extern compop_func op_410_0_comp_ff;
extern compop_func op_418_0_comp_ff;
extern compop_func op_420_0_comp_ff;
extern compop_func op_428_0_comp_ff;
extern compop_func op_430_0_comp_ff;
extern compop_func op_438_0_comp_ff;
extern compop_func op_439_0_comp_ff;
extern compop_func op_440_0_comp_ff;
extern compop_func op_450_0_comp_ff;
extern compop_func op_458_0_comp_ff;
extern compop_func op_460_0_comp_ff;
extern compop_func op_468_0_comp_ff;
extern compop_func op_470_0_comp_ff;
extern compop_func op_478_0_comp_ff;
extern compop_func op_479_0_comp_ff;
extern compop_func op_480_0_comp_ff;
extern compop_func op_490_0_comp_ff;
extern compop_func op_498_0_comp_ff;
extern compop_func op_4a0_0_comp_ff;
extern compop_func op_4a8_0_comp_ff;
extern compop_func op_4b0_0_comp_ff;
extern compop_func op_4b8_0_comp_ff;
extern compop_func op_4b9_0_comp_ff;
extern compop_func op_600_0_comp_ff;
extern compop_func op_610_0_comp_ff;
extern compop_func op_618_0_comp_ff;
extern compop_func op_620_0_comp_ff;
extern compop_func op_628_0_comp_ff;
extern compop_func op_630_0_comp_ff;
extern compop_func op_638_0_comp_ff;
extern compop_func op_639_0_comp_ff;
extern compop_func op_640_0_comp_ff;
extern compop_func op_650_0_comp_ff;
extern compop_func op_658_0_comp_ff;
extern compop_func op_660_0_comp_ff;
extern compop_func op_668_0_comp_ff;
extern compop_func op_670_0_comp_ff;
extern compop_func op_678_0_comp_ff;
extern compop_func op_679_0_comp_ff;
extern compop_func op_680_0_comp_ff;
extern compop_func op_690_0_comp_ff;
extern compop_func op_698_0_comp_ff;
extern compop_func op_6a0_0_comp_ff;
extern compop_func op_6a8_0_comp_ff;
extern compop_func op_6b0_0_comp_ff;
extern compop_func op_6b8_0_comp_ff;
extern compop_func op_6b9_0_comp_ff;
extern compop_func op_800_0_comp_ff;
extern compop_func op_810_0_comp_ff;
extern compop_func op_818_0_comp_ff;
extern compop_func op_820_0_comp_ff;
extern compop_func op_828_0_comp_ff;
extern compop_func op_830_0_comp_ff;
extern compop_func op_838_0_comp_ff;
extern compop_func op_839_0_comp_ff;
extern compop_func op_83a_0_comp_ff;
extern compop_func op_83b_0_comp_ff;
extern compop_func op_840_0_comp_ff;
extern compop_func op_850_0_comp_ff;
extern compop_func op_858_0_comp_ff;
extern compop_func op_860_0_comp_ff;
extern compop_func op_868_0_comp_ff;
extern compop_func op_870_0_comp_ff;
extern compop_func op_878_0_comp_ff;
extern compop_func op_879_0_comp_ff;
extern compop_func op_880_0_comp_ff;
extern compop_func op_890_0_comp_ff;
extern compop_func op_898_0_comp_ff;
extern compop_func op_8a0_0_comp_ff;
extern compop_func op_8a8_0_comp_ff;
extern compop_func op_8b0_0_comp_ff;
extern compop_func op_8b8_0_comp_ff;
extern compop_func op_8b9_0_comp_ff;
extern compop_func op_8c0_0_comp_ff;
extern compop_func op_8d0_0_comp_ff;
extern compop_func op_8d8_0_comp_ff;
extern compop_func op_8e0_0_comp_ff;
extern compop_func op_8e8_0_comp_ff;
extern compop_func op_8f0_0_comp_ff;
extern compop_func op_8f8_0_comp_ff;
extern compop_func op_8f9_0_comp_ff;
extern compop_func op_a00_0_comp_ff;
extern compop_func op_a10_0_comp_ff;
extern compop_func op_a18_0_comp_ff;
extern compop_func op_a20_0_comp_ff;
extern compop_func op_a28_0_comp_ff;
extern compop_func op_a30_0_comp_ff;
extern compop_func op_a38_0_comp_ff;
extern compop_func op_a39_0_comp_ff;
extern compop_func op_a3c_0_comp_ff;
extern compop_func op_a40_0_comp_ff;
extern compop_func op_a50_0_comp_ff;
extern compop_func op_a58_0_comp_ff;
extern compop_func op_a60_0_comp_ff;
extern compop_func op_a68_0_comp_ff;
extern compop_func op_a70_0_comp_ff;
extern compop_func op_a78_0_comp_ff;
extern compop_func op_a79_0_comp_ff;
extern compop_func op_a80_0_comp_ff;
extern compop_func op_a90_0_comp_ff;
extern compop_func op_a98_0_comp_ff;
extern compop_func op_aa0_0_comp_ff;
extern compop_func op_aa8_0_comp_ff;
extern compop_func op_ab0_0_comp_ff;
extern compop_func op_ab8_0_comp_ff;
extern compop_func op_ab9_0_comp_ff;
extern compop_func op_c00_0_comp_ff;
extern compop_func op_c10_0_comp_ff;
extern compop_func op_c18_0_comp_ff;
extern compop_func op_c20_0_comp_ff;
extern compop_func op_c28_0_comp_ff;
extern compop_func op_c30_0_comp_ff;
extern compop_func op_c38_0_comp_ff;
extern compop_func op_c39_0_comp_ff;
extern compop_func op_c3a_0_comp_ff;
extern compop_func op_c3b_0_comp_ff;
extern compop_func op_c40_0_comp_ff;
extern compop_func op_c50_0_comp_ff;
extern compop_func op_c58_0_comp_ff;
extern compop_func op_c60_0_comp_ff;
extern compop_func op_c68_0_comp_ff;
extern compop_func op_c70_0_comp_ff;
extern compop_func op_c78_0_comp_ff;
extern compop_func op_c79_0_comp_ff;
extern compop_func op_c7a_0_comp_ff;
extern compop_func op_c7b_0_comp_ff;
extern compop_func op_c80_0_comp_ff;
extern compop_func op_c90_0_comp_ff;
extern compop_func op_c98_0_comp_ff;
extern compop_func op_ca0_0_comp_ff;
extern compop_func op_ca8_0_comp_ff;
extern compop_func op_cb0_0_comp_ff;
extern compop_func op_cb8_0_comp_ff;
extern compop_func op_cb9_0_comp_ff;
extern compop_func op_cba_0_comp_ff;
extern compop_func op_cbb_0_comp_ff;
extern compop_func op_1000_0_comp_ff;
extern compop_func op_1010_0_comp_ff;
extern compop_func op_1018_0_comp_ff;
extern compop_func op_1020_0_comp_ff;
extern compop_func op_1028_0_comp_ff;
extern compop_func op_1030_0_comp_ff;
extern compop_func op_1038_0_comp_ff;
extern compop_func op_1039_0_comp_ff;
extern compop_func op_103a_0_comp_ff;
extern compop_func op_103b_0_comp_ff;
extern compop_func op_103c_0_comp_ff;
extern compop_func op_1080_0_comp_ff;
extern compop_func op_1090_0_comp_ff;
extern compop_func op_1098_0_comp_ff;
extern compop_func op_10a0_0_comp_ff;
extern compop_func op_10a8_0_comp_ff;
extern compop_func op_10b0_0_comp_ff;
extern compop_func op_10b8_0_comp_ff;
extern compop_func op_10b9_0_comp_ff;
extern compop_func op_10ba_0_comp_ff;
extern compop_func op_10bb_0_comp_ff;
extern compop_func op_10bc_0_comp_ff;
extern compop_func op_10c0_0_comp_ff;
extern compop_func op_10d0_0_comp_ff;
extern compop_func op_10d8_0_comp_ff;
extern compop_func op_10e0_0_comp_ff;
extern compop_func op_10e8_0_comp_ff;
extern compop_func op_10f0_0_comp_ff;
extern compop_func op_10f8_0_comp_ff;
extern compop_func op_10f9_0_comp_ff;
extern compop_func op_10fa_0_comp_ff;
extern compop_func op_10fb_0_comp_ff;
extern compop_func op_10fc_0_comp_ff;
extern compop_func op_1100_0_comp_ff;
extern compop_func op_1110_0_comp_ff;
extern compop_func op_1118_0_comp_ff;
extern compop_func op_1120_0_comp_ff;
extern compop_func op_1128_0_comp_ff;
extern compop_func op_1130_0_comp_ff;
extern compop_func op_1138_0_comp_ff;
extern compop_func op_1139_0_comp_ff;
extern compop_func op_113a_0_comp_ff;
extern compop_func op_113b_0_comp_ff;
extern compop_func op_113c_0_comp_ff;
extern compop_func op_1140_0_comp_ff;
extern compop_func op_1150_0_comp_ff;
extern compop_func op_1158_0_comp_ff;
extern compop_func op_1160_0_comp_ff;
extern compop_func op_1168_0_comp_ff;
extern compop_func op_1170_0_comp_ff;
extern compop_func op_1178_0_comp_ff;
extern compop_func op_1179_0_comp_ff;
extern compop_func op_117a_0_comp_ff;
extern compop_func op_117b_0_comp_ff;
extern compop_func op_117c_0_comp_ff;
extern compop_func op_1180_0_comp_ff;
extern compop_func op_1190_0_comp_ff;
extern compop_func op_1198_0_comp_ff;
extern compop_func op_11a0_0_comp_ff;
extern compop_func op_11a8_0_comp_ff;
extern compop_func op_11b0_0_comp_ff;
extern compop_func op_11b8_0_comp_ff;
extern compop_func op_11b9_0_comp_ff;
extern compop_func op_11ba_0_comp_ff;
extern compop_func op_11bb_0_comp_ff;
extern compop_func op_11bc_0_comp_ff;
extern compop_func op_11c0_0_comp_ff;
extern compop_func op_11d0_0_comp_ff;
extern compop_func op_11d8_0_comp_ff;
extern compop_func op_11e0_0_comp_ff;
extern compop_func op_11e8_0_comp_ff;
extern compop_func op_11f0_0_comp_ff;
extern compop_func op_11f8_0_comp_ff;
extern compop_func op_11f9_0_comp_ff;
extern compop_func op_11fa_0_comp_ff;
extern compop_func op_11fb_0_comp_ff;
extern compop_func op_11fc_0_comp_ff;
extern compop_func op_13c0_0_comp_ff;
extern compop_func op_13d0_0_comp_ff;
extern compop_func op_13d8_0_comp_ff;
extern compop_func op_13e0_0_comp_ff;
extern compop_func op_13e8_0_comp_ff;
extern compop_func op_13f0_0_comp_ff;
extern compop_func op_13f8_0_comp_ff;
extern compop_func op_13f9_0_comp_ff;
extern compop_func op_13fa_0_comp_ff;
extern compop_func op_13fb_0_comp_ff;
extern compop_func op_13fc_0_comp_ff;
extern compop_func op_2000_0_comp_ff;
extern compop_func op_2008_0_comp_ff;
extern compop_func op_2010_0_comp_ff;
extern compop_func op_2018_0_comp_ff;
extern compop_func op_2020_0_comp_ff;
extern compop_func op_2028_0_comp_ff;
extern compop_func op_2030_0_comp_ff;
extern compop_func op_2038_0_comp_ff;
extern compop_func op_2039_0_comp_ff;
extern compop_func op_203a_0_comp_ff;
extern compop_func op_203b_0_comp_ff;
extern compop_func op_203c_0_comp_ff;
extern compop_func op_2040_0_comp_ff;
extern compop_func op_2048_0_comp_ff;
extern compop_func op_2050_0_comp_ff;
extern compop_func op_2058_0_comp_ff;
extern compop_func op_2060_0_comp_ff;
extern compop_func op_2068_0_comp_ff;
extern compop_func op_2070_0_comp_ff;
extern compop_func op_2078_0_comp_ff;
extern compop_func op_2079_0_comp_ff;
extern compop_func op_207a_0_comp_ff;
extern compop_func op_207b_0_comp_ff;
extern compop_func op_207c_0_comp_ff;
extern compop_func op_2080_0_comp_ff;
extern compop_func op_2088_0_comp_ff;
extern compop_func op_2090_0_comp_ff;
extern compop_func op_2098_0_comp_ff;
extern compop_func op_20a0_0_comp_ff;
extern compop_func op_20a8_0_comp_ff;
extern compop_func op_20b0_0_comp_ff;
extern compop_func op_20b8_0_comp_ff;
extern compop_func op_20b9_0_comp_ff;
extern compop_func op_20ba_0_comp_ff;
extern compop_func op_20bb_0_comp_ff;
extern compop_func op_20bc_0_comp_ff;
extern compop_func op_20c0_0_comp_ff;
extern compop_func op_20c8_0_comp_ff;
extern compop_func op_20d0_0_comp_ff;
extern compop_func op_20d8_0_comp_ff;
extern compop_func op_20e0_0_comp_ff;
extern compop_func op_20e8_0_comp_ff;
extern compop_func op_20f0_0_comp_ff;
extern compop_func op_20f8_0_comp_ff;
extern compop_func op_20f9_0_comp_ff;
extern compop_func op_20fa_0_comp_ff;
extern compop_func op_20fb_0_comp_ff;
extern compop_func op_20fc_0_comp_ff;
extern compop_func op_2100_0_comp_ff;
extern compop_func op_2108_0_comp_ff;
extern compop_func op_2110_0_comp_ff;
extern compop_func op_2118_0_comp_ff;
extern compop_func op_2120_0_comp_ff;
extern compop_func op_2128_0_comp_ff;
extern compop_func op_2130_0_comp_ff;
extern compop_func op_2138_0_comp_ff;
extern compop_func op_2139_0_comp_ff;
extern compop_func op_213a_0_comp_ff;
extern compop_func op_213b_0_comp_ff;
extern compop_func op_213c_0_comp_ff;
extern compop_func op_2140_0_comp_ff;
extern compop_func op_2148_0_comp_ff;
extern compop_func op_2150_0_comp_ff;
extern compop_func op_2158_0_comp_ff;
extern compop_func op_2160_0_comp_ff;
extern compop_func op_2168_0_comp_ff;
extern compop_func op_2170_0_comp_ff;
extern compop_func op_2178_0_comp_ff;
extern compop_func op_2179_0_comp_ff;
extern compop_func op_217a_0_comp_ff;
extern compop_func op_217b_0_comp_ff;
extern compop_func op_217c_0_comp_ff;
extern compop_func op_2180_0_comp_ff;
extern compop_func op_2188_0_comp_ff;
extern compop_func op_2190_0_comp_ff;
extern compop_func op_2198_0_comp_ff;
extern compop_func op_21a0_0_comp_ff;
extern compop_func op_21a8_0_comp_ff;
extern compop_func op_21b0_0_comp_ff;
extern compop_func op_21b8_0_comp_ff;
extern compop_func op_21b9_0_comp_ff;
extern compop_func op_21ba_0_comp_ff;
extern compop_func op_21bb_0_comp_ff;
extern compop_func op_21bc_0_comp_ff;
extern compop_func op_21c0_0_comp_ff;
extern compop_func op_21c8_0_comp_ff;
extern compop_func op_21d0_0_comp_ff;
extern compop_func op_21d8_0_comp_ff;
extern compop_func op_21e0_0_comp_ff;
extern compop_func op_21e8_0_comp_ff;
extern compop_func op_21f0_0_comp_ff;
extern compop_func op_21f8_0_comp_ff;
extern compop_func op_21f9_0_comp_ff;
extern compop_func op_21fa_0_comp_ff;
extern compop_func op_21fb_0_comp_ff;
extern compop_func op_21fc_0_comp_ff;
extern compop_func op_23c0_0_comp_ff;
extern compop_func op_23c8_0_comp_ff;
extern compop_func op_23d0_0_comp_ff;
extern compop_func op_23d8_0_comp_ff;
extern compop_func op_23e0_0_comp_ff;
extern compop_func op_23e8_0_comp_ff;
extern compop_func op_23f0_0_comp_ff;
extern compop_func op_23f8_0_comp_ff;
extern compop_func op_23f9_0_comp_ff;
extern compop_func op_23fa_0_comp_ff;
extern compop_func op_23fb_0_comp_ff;
extern compop_func op_23fc_0_comp_ff;
extern compop_func op_3000_0_comp_ff;
extern compop_func op_3008_0_comp_ff;
extern compop_func op_3010_0_comp_ff;
extern compop_func op_3018_0_comp_ff;
extern compop_func op_3020_0_comp_ff;
extern compop_func op_3028_0_comp_ff;
extern compop_func op_3030_0_comp_ff;
extern compop_func op_3038_0_comp_ff;
extern compop_func op_3039_0_comp_ff;
extern compop_func op_303a_0_comp_ff;
extern compop_func op_303b_0_comp_ff;
extern compop_func op_303c_0_comp_ff;
extern compop_func op_3040_0_comp_ff;
extern compop_func op_3048_0_comp_ff;
extern compop_func op_3050_0_comp_ff;
extern compop_func op_3058_0_comp_ff;
extern compop_func op_3060_0_comp_ff;
extern compop_func op_3068_0_comp_ff;
extern compop_func op_3070_0_comp_ff;
extern compop_func op_3078_0_comp_ff;
extern compop_func op_3079_0_comp_ff;
extern compop_func op_307a_0_comp_ff;
extern compop_func op_307b_0_comp_ff;
extern compop_func op_307c_0_comp_ff;
extern compop_func op_3080_0_comp_ff;
extern compop_func op_3088_0_comp_ff;
extern compop_func op_3090_0_comp_ff;
extern compop_func op_3098_0_comp_ff;
extern compop_func op_30a0_0_comp_ff;
extern compop_func op_30a8_0_comp_ff;
extern compop_func op_30b0_0_comp_ff;
extern compop_func op_30b8_0_comp_ff;
extern compop_func op_30b9_0_comp_ff;
extern compop_func op_30ba_0_comp_ff;
extern compop_func op_30bb_0_comp_ff;
extern compop_func op_30bc_0_comp_ff;
extern compop_func op_30c0_0_comp_ff;
extern compop_func op_30c8_0_comp_ff;
extern compop_func op_30d0_0_comp_ff;
extern compop_func op_30d8_0_comp_ff;
extern compop_func op_30e0_0_comp_ff;
extern compop_func op_30e8_0_comp_ff;
extern compop_func op_30f0_0_comp_ff;
extern compop_func op_30f8_0_comp_ff;
extern compop_func op_30f9_0_comp_ff;
extern compop_func op_30fa_0_comp_ff;
extern compop_func op_30fb_0_comp_ff;
extern compop_func op_30fc_0_comp_ff;
extern compop_func op_3100_0_comp_ff;
extern compop_func op_3108_0_comp_ff;
extern compop_func op_3110_0_comp_ff;
extern compop_func op_3118_0_comp_ff;
extern compop_func op_3120_0_comp_ff;
extern compop_func op_3128_0_comp_ff;
extern compop_func op_3130_0_comp_ff;
extern compop_func op_3138_0_comp_ff;
extern compop_func op_3139_0_comp_ff;
extern compop_func op_313a_0_comp_ff;
extern compop_func op_313b_0_comp_ff;
extern compop_func op_313c_0_comp_ff;
extern compop_func op_3140_0_comp_ff;
extern compop_func op_3148_0_comp_ff;
extern compop_func op_3150_0_comp_ff;
extern compop_func op_3158_0_comp_ff;
extern compop_func op_3160_0_comp_ff;
extern compop_func op_3168_0_comp_ff;
extern compop_func op_3170_0_comp_ff;
extern compop_func op_3178_0_comp_ff;
extern compop_func op_3179_0_comp_ff;
extern compop_func op_317a_0_comp_ff;
extern compop_func op_317b_0_comp_ff;
extern compop_func op_317c_0_comp_ff;
extern compop_func op_3180_0_comp_ff;
extern compop_func op_3188_0_comp_ff;
extern compop_func op_3190_0_comp_ff;
extern compop_func op_3198_0_comp_ff;
extern compop_func op_31a0_0_comp_ff;
extern compop_func op_31a8_0_comp_ff;
extern compop_func op_31b0_0_comp_ff;
extern compop_func op_31b8_0_comp_ff;
extern compop_func op_31b9_0_comp_ff;
extern compop_func op_31ba_0_comp_ff;
extern compop_func op_31bb_0_comp_ff;
extern compop_func op_31bc_0_comp_ff;
extern compop_func op_31c0_0_comp_ff;
extern compop_func op_31c8_0_comp_ff;
extern compop_func op_31d0_0_comp_ff;
extern compop_func op_31d8_0_comp_ff;
extern compop_func op_31e0_0_comp_ff;
extern compop_func op_31e8_0_comp_ff;
extern compop_func op_31f0_0_comp_ff;
extern compop_func op_31f8_0_comp_ff;
extern compop_func op_31f9_0_comp_ff;
extern compop_func op_31fa_0_comp_ff;
extern compop_func op_31fb_0_comp_ff;
extern compop_func op_31fc_0_comp_ff;
extern compop_func op_33c0_0_comp_ff;
extern compop_func op_33c8_0_comp_ff;
extern compop_func op_33d0_0_comp_ff;
extern compop_func op_33d8_0_comp_ff;
extern compop_func op_33e0_0_comp_ff;
extern compop_func op_33e8_0_comp_ff;
extern compop_func op_33f0_0_comp_ff;
extern compop_func op_33f8_0_comp_ff;
extern compop_func op_33f9_0_comp_ff;
extern compop_func op_33fa_0_comp_ff;
extern compop_func op_33fb_0_comp_ff;
extern compop_func op_33fc_0_comp_ff;
extern compop_func op_4000_0_comp_ff;
extern compop_func op_4010_0_comp_ff;
extern compop_func op_4018_0_comp_ff;
extern compop_func op_4020_0_comp_ff;
extern compop_func op_4028_0_comp_ff;
extern compop_func op_4030_0_comp_ff;
extern compop_func op_4038_0_comp_ff;
extern compop_func op_4039_0_comp_ff;
extern compop_func op_4040_0_comp_ff;
extern compop_func op_4050_0_comp_ff;
extern compop_func op_4058_0_comp_ff;
extern compop_func op_4060_0_comp_ff;
extern compop_func op_4068_0_comp_ff;
extern compop_func op_4070_0_comp_ff;
extern compop_func op_4078_0_comp_ff;
extern compop_func op_4079_0_comp_ff;
extern compop_func op_4080_0_comp_ff;
extern compop_func op_4090_0_comp_ff;
extern compop_func op_4098_0_comp_ff;
extern compop_func op_40a0_0_comp_ff;
extern compop_func op_40a8_0_comp_ff;
extern compop_func op_40b0_0_comp_ff;
extern compop_func op_40b8_0_comp_ff;
extern compop_func op_40b9_0_comp_ff;
extern compop_func op_41d0_0_comp_ff;
extern compop_func op_41e8_0_comp_ff;
extern compop_func op_41f0_0_comp_ff;
extern compop_func op_41f8_0_comp_ff;
extern compop_func op_41f9_0_comp_ff;
extern compop_func op_41fa_0_comp_ff;
extern compop_func op_41fb_0_comp_ff;
extern compop_func op_4200_0_comp_ff;
extern compop_func op_4210_0_comp_ff;
extern compop_func op_4218_0_comp_ff;
extern compop_func op_4220_0_comp_ff;
extern compop_func op_4228_0_comp_ff;
extern compop_func op_4230_0_comp_ff;
extern compop_func op_4238_0_comp_ff;
extern compop_func op_4239_0_comp_ff;
extern compop_func op_4240_0_comp_ff;
extern compop_func op_4250_0_comp_ff;
extern compop_func op_4258_0_comp_ff;
extern compop_func op_4260_0_comp_ff;
extern compop_func op_4268_0_comp_ff;
extern compop_func op_4270_0_comp_ff;
extern compop_func op_4278_0_comp_ff;
extern compop_func op_4279_0_comp_ff;
extern compop_func op_4280_0_comp_ff;
extern compop_func op_4290_0_comp_ff;
extern compop_func op_4298_0_comp_ff;
extern compop_func op_42a0_0_comp_ff;
extern compop_func op_42a8_0_comp_ff;
extern compop_func op_42b0_0_comp_ff;
extern compop_func op_42b8_0_comp_ff;
extern compop_func op_42b9_0_comp_ff;
extern compop_func op_4400_0_comp_ff;
extern compop_func op_4410_0_comp_ff;
extern compop_func op_4418_0_comp_ff;
extern compop_func op_4420_0_comp_ff;
extern compop_func op_4428_0_comp_ff;
extern compop_func op_4430_0_comp_ff;
extern compop_func op_4438_0_comp_ff;
extern compop_func op_4439_0_comp_ff;
extern compop_func op_4440_0_comp_ff;
extern compop_func op_4450_0_comp_ff;
extern compop_func op_4458_0_comp_ff;
extern compop_func op_4460_0_comp_ff;
extern compop_func op_4468_0_comp_ff;
extern compop_func op_4470_0_comp_ff;
extern compop_func op_4478_0_comp_ff;
extern compop_func op_4479_0_comp_ff;
extern compop_func op_4480_0_comp_ff;
extern compop_func op_4490_0_comp_ff;
extern compop_func op_4498_0_comp_ff;
extern compop_func op_44a0_0_comp_ff;
extern compop_func op_44a8_0_comp_ff;
extern compop_func op_44b0_0_comp_ff;
extern compop_func op_44b8_0_comp_ff;
extern compop_func op_44b9_0_comp_ff;
extern compop_func op_4600_0_comp_ff;
extern compop_func op_4610_0_comp_ff;
extern compop_func op_4618_0_comp_ff;
extern compop_func op_4620_0_comp_ff;
extern compop_func op_4628_0_comp_ff;
extern compop_func op_4630_0_comp_ff;
extern compop_func op_4638_0_comp_ff;
extern compop_func op_4639_0_comp_ff;
extern compop_func op_4640_0_comp_ff;
extern compop_func op_4650_0_comp_ff;
extern compop_func op_4658_0_comp_ff;
extern compop_func op_4660_0_comp_ff;
extern compop_func op_4668_0_comp_ff;
extern compop_func op_4670_0_comp_ff;
extern compop_func op_4678_0_comp_ff;
extern compop_func op_4679_0_comp_ff;
extern compop_func op_4680_0_comp_ff;
extern compop_func op_4690_0_comp_ff;
extern compop_func op_4698_0_comp_ff;
extern compop_func op_46a0_0_comp_ff;
extern compop_func op_46a8_0_comp_ff;
extern compop_func op_46b0_0_comp_ff;
extern compop_func op_46b8_0_comp_ff;
extern compop_func op_46b9_0_comp_ff;
extern compop_func op_4808_0_comp_ff;
extern compop_func op_4840_0_comp_ff;
extern compop_func op_4850_0_comp_ff;
extern compop_func op_4868_0_comp_ff;
extern compop_func op_4870_0_comp_ff;
extern compop_func op_4878_0_comp_ff;
extern compop_func op_4879_0_comp_ff;
extern compop_func op_487a_0_comp_ff;
extern compop_func op_487b_0_comp_ff;
extern compop_func op_4880_0_comp_ff;
extern compop_func op_4890_0_comp_ff;
extern compop_func op_48a0_0_comp_ff;
extern compop_func op_48a8_0_comp_ff;
extern compop_func op_48b0_0_comp_ff;
extern compop_func op_48b8_0_comp_ff;
extern compop_func op_48b9_0_comp_ff;
extern compop_func op_48c0_0_comp_ff;
extern compop_func op_48d0_0_comp_ff;
extern compop_func op_48e0_0_comp_ff;
extern compop_func op_48e8_0_comp_ff;
extern compop_func op_48f0_0_comp_ff;
extern compop_func op_48f8_0_comp_ff;
extern compop_func op_48f9_0_comp_ff;
extern compop_func op_49c0_0_comp_ff;
extern compop_func op_4a00_0_comp_ff;
extern compop_func op_4a10_0_comp_ff;
extern compop_func op_4a18_0_comp_ff;
extern compop_func op_4a20_0_comp_ff;
extern compop_func op_4a28_0_comp_ff;
extern compop_func op_4a30_0_comp_ff;
extern compop_func op_4a38_0_comp_ff;
extern compop_func op_4a39_0_comp_ff;
extern compop_func op_4a3a_0_comp_ff;
extern compop_func op_4a3b_0_comp_ff;
extern compop_func op_4a40_0_comp_ff;
extern compop_func op_4a48_0_comp_ff;
extern compop_func op_4a50_0_comp_ff;
extern compop_func op_4a58_0_comp_ff;
extern compop_func op_4a60_0_comp_ff;
extern compop_func op_4a68_0_comp_ff;
extern compop_func op_4a70_0_comp_ff;
extern compop_func op_4a78_0_comp_ff;
extern compop_func op_4a79_0_comp_ff;
extern compop_func op_4a7a_0_comp_ff;
extern compop_func op_4a7b_0_comp_ff;
extern compop_func op_4a80_0_comp_ff;
extern compop_func op_4a88_0_comp_ff;
extern compop_func op_4a90_0_comp_ff;
extern compop_func op_4a98_0_comp_ff;
extern compop_func op_4aa0_0_comp_ff;
extern compop_func op_4aa8_0_comp_ff;
extern compop_func op_4ab0_0_comp_ff;
extern compop_func op_4ab8_0_comp_ff;
extern compop_func op_4ab9_0_comp_ff;
extern compop_func op_4aba_0_comp_ff;
extern compop_func op_4abb_0_comp_ff;
extern compop_func op_4c00_0_comp_ff;
extern compop_func op_4c10_0_comp_ff;
extern compop_func op_4c18_0_comp_ff;
extern compop_func op_4c20_0_comp_ff;
extern compop_func op_4c28_0_comp_ff;
extern compop_func op_4c30_0_comp_ff;
extern compop_func op_4c38_0_comp_ff;
extern compop_func op_4c39_0_comp_ff;
extern compop_func op_4c3a_0_comp_ff;
extern compop_func op_4c3b_0_comp_ff;
extern compop_func op_4c3c_0_comp_ff;
extern compop_func op_4c90_0_comp_ff;
extern compop_func op_4c98_0_comp_ff;
extern compop_func op_4ca8_0_comp_ff;
extern compop_func op_4cb0_0_comp_ff;
extern compop_func op_4cb8_0_comp_ff;
extern compop_func op_4cb9_0_comp_ff;
extern compop_func op_4cba_0_comp_ff;
extern compop_func op_4cbb_0_comp_ff;
extern compop_func op_4cd0_0_comp_ff;
extern compop_func op_4cd8_0_comp_ff;
extern compop_func op_4ce8_0_comp_ff;
extern compop_func op_4cf0_0_comp_ff;
extern compop_func op_4cf8_0_comp_ff;
extern compop_func op_4cf9_0_comp_ff;
extern compop_func op_4cfa_0_comp_ff;
extern compop_func op_4cfb_0_comp_ff;
extern compop_func op_4e50_0_comp_ff;
extern compop_func op_4e58_0_comp_ff;
extern compop_func op_4e71_0_comp_ff;
extern compop_func op_4e74_0_comp_ff;
extern compop_func op_4e75_0_comp_ff;
extern compop_func op_4e90_0_comp_ff;
extern compop_func op_4ea8_0_comp_ff;
extern compop_func op_4eb0_0_comp_ff;
extern compop_func op_4eb8_0_comp_ff;
extern compop_func op_4eb9_0_comp_ff;
extern compop_func op_4eba_0_comp_ff;
extern compop_func op_4ebb_0_comp_ff;
extern compop_func op_4ed0_0_comp_ff;
extern compop_func op_4ee8_0_comp_ff;
extern compop_func op_4ef0_0_comp_ff;
extern compop_func op_4ef8_0_comp_ff;
extern compop_func op_4ef9_0_comp_ff;
extern compop_func op_4efa_0_comp_ff;
extern compop_func op_4efb_0_comp_ff;
extern compop_func op_5000_0_comp_ff;
extern compop_func op_5010_0_comp_ff;
extern compop_func op_5018_0_comp_ff;
extern compop_func op_5020_0_comp_ff;
extern compop_func op_5028_0_comp_ff;
extern compop_func op_5030_0_comp_ff;
extern compop_func op_5038_0_comp_ff;
extern compop_func op_5039_0_comp_ff;
extern compop_func op_5040_0_comp_ff;
extern compop_func op_5048_0_comp_ff;
extern compop_func op_5050_0_comp_ff;
extern compop_func op_5058_0_comp_ff;
extern compop_func op_5060_0_comp_ff;
extern compop_func op_5068_0_comp_ff;
extern compop_func op_5070_0_comp_ff;
extern compop_func op_5078_0_comp_ff;
extern compop_func op_5079_0_comp_ff;
extern compop_func op_5080_0_comp_ff;
extern compop_func op_5088_0_comp_ff;
extern compop_func op_5090_0_comp_ff;
extern compop_func op_5098_0_comp_ff;
extern compop_func op_50a0_0_comp_ff;
extern compop_func op_50a8_0_comp_ff;
extern compop_func op_50b0_0_comp_ff;
extern compop_func op_50b8_0_comp_ff;
extern compop_func op_50b9_0_comp_ff;
extern compop_func op_50c0_0_comp_ff;
extern compop_func op_50c8_0_comp_ff;
extern compop_func op_50d0_0_comp_ff;
extern compop_func op_50d8_0_comp_ff;
extern compop_func op_50e0_0_comp_ff;
extern compop_func op_50e8_0_comp_ff;
extern compop_func op_50f0_0_comp_ff;
extern compop_func op_50f8_0_comp_ff;
extern compop_func op_50f9_0_comp_ff;
extern compop_func op_5100_0_comp_ff;
extern compop_func op_5110_0_comp_ff;
extern compop_func op_5118_0_comp_ff;
extern compop_func op_5120_0_comp_ff;
extern compop_func op_5128_0_comp_ff;
extern compop_func op_5130_0_comp_ff;
extern compop_func op_5138_0_comp_ff;
extern compop_func op_5139_0_comp_ff;
extern compop_func op_5140_0_comp_ff;
extern compop_func op_5148_0_comp_ff;
extern compop_func op_5150_0_comp_ff;
extern compop_func op_5158_0_comp_ff;
extern compop_func op_5160_0_comp_ff;
extern compop_func op_5168_0_comp_ff;
extern compop_func op_5170_0_comp_ff;
extern compop_func op_5178_0_comp_ff;
extern compop_func op_5179_0_comp_ff;
extern compop_func op_5180_0_comp_ff;
extern compop_func op_5188_0_comp_ff;
extern compop_func op_5190_0_comp_ff;
extern compop_func op_5198_0_comp_ff;
extern compop_func op_51a0_0_comp_ff;
extern compop_func op_51a8_0_comp_ff;
extern compop_func op_51b0_0_comp_ff;
extern compop_func op_51b8_0_comp_ff;
extern compop_func op_51b9_0_comp_ff;
extern compop_func op_51c0_0_comp_ff;
extern compop_func op_51c8_0_comp_ff;
extern compop_func op_51d0_0_comp_ff;
extern compop_func op_51d8_0_comp_ff;
extern compop_func op_51e0_0_comp_ff;
extern compop_func op_51e8_0_comp_ff;
extern compop_func op_51f0_0_comp_ff;
extern compop_func op_51f8_0_comp_ff;
extern compop_func op_51f9_0_comp_ff;
extern compop_func op_52c0_0_comp_ff;
extern compop_func op_52c8_0_comp_ff;
extern compop_func op_52d0_0_comp_ff;
extern compop_func op_52d8_0_comp_ff;
extern compop_func op_52e0_0_comp_ff;
extern compop_func op_52e8_0_comp_ff;
extern compop_func op_52f0_0_comp_ff;
extern compop_func op_52f8_0_comp_ff;
extern compop_func op_52f9_0_comp_ff;
extern compop_func op_53c0_0_comp_ff;
extern compop_func op_53c8_0_comp_ff;
extern compop_func op_53d0_0_comp_ff;
extern compop_func op_53d8_0_comp_ff;
extern compop_func op_53e0_0_comp_ff;
extern compop_func op_53e8_0_comp_ff;
extern compop_func op_53f0_0_comp_ff;
extern compop_func op_53f8_0_comp_ff;
extern compop_func op_53f9_0_comp_ff;
extern compop_func op_54c0_0_comp_ff;
extern compop_func op_54c8_0_comp_ff;
extern compop_func op_54d0_0_comp_ff;
extern compop_func op_54d8_0_comp_ff;
extern compop_func op_54e0_0_comp_ff;
extern compop_func op_54e8_0_comp_ff;
extern compop_func op_54f0_0_comp_ff;
extern compop_func op_54f8_0_comp_ff;
extern compop_func op_54f9_0_comp_ff;
extern compop_func op_55c0_0_comp_ff;
extern compop_func op_55c8_0_comp_ff;
extern compop_func op_55d0_0_comp_ff;
extern compop_func op_55d8_0_comp_ff;
extern compop_func op_55e0_0_comp_ff;
extern compop_func op_55e8_0_comp_ff;
extern compop_func op_55f0_0_comp_ff;
extern compop_func op_55f8_0_comp_ff;
extern compop_func op_55f9_0_comp_ff;
extern compop_func op_56c0_0_comp_ff;
extern compop_func op_56c8_0_comp_ff;
extern compop_func op_56d0_0_comp_ff;
extern compop_func op_56d8_0_comp_ff;
extern compop_func op_56e0_0_comp_ff;
extern compop_func op_56e8_0_comp_ff;
extern compop_func op_56f0_0_comp_ff;
extern compop_func op_56f8_0_comp_ff;
extern compop_func op_56f9_0_comp_ff;
extern compop_func op_57c0_0_comp_ff;
extern compop_func op_57c8_0_comp_ff;
extern compop_func op_57d0_0_comp_ff;
extern compop_func op_57d8_0_comp_ff;
extern compop_func op_57e0_0_comp_ff;
extern compop_func op_57e8_0_comp_ff;
extern compop_func op_57f0_0_comp_ff;
extern compop_func op_57f8_0_comp_ff;
extern compop_func op_57f9_0_comp_ff;
extern compop_func op_58c0_0_comp_ff;
extern compop_func op_58c8_0_comp_ff;
extern compop_func op_58d0_0_comp_ff;
extern compop_func op_58d8_0_comp_ff;
extern compop_func op_58e0_0_comp_ff;
extern compop_func op_58e8_0_comp_ff;
extern compop_func op_58f0_0_comp_ff;
extern compop_func op_58f8_0_comp_ff;
extern compop_func op_58f9_0_comp_ff;
extern compop_func op_59c0_0_comp_ff;
extern compop_func op_59c8_0_comp_ff;
extern compop_func op_59d0_0_comp_ff;
extern compop_func op_59d8_0_comp_ff;
extern compop_func op_59e0_0_comp_ff;
extern compop_func op_59e8_0_comp_ff;
extern compop_func op_59f0_0_comp_ff;
extern compop_func op_59f8_0_comp_ff;
extern compop_func op_59f9_0_comp_ff;
extern compop_func op_5ac0_0_comp_ff;
extern compop_func op_5ac8_0_comp_ff;
extern compop_func op_5ad0_0_comp_ff;
extern compop_func op_5ad8_0_comp_ff;
extern compop_func op_5ae0_0_comp_ff;
extern compop_func op_5ae8_0_comp_ff;
extern compop_func op_5af0_0_comp_ff;
extern compop_func op_5af8_0_comp_ff;
extern compop_func op_5af9_0_comp_ff;
extern compop_func op_5bc0_0_comp_ff;
extern compop_func op_5bc8_0_comp_ff;
extern compop_func op_5bd0_0_comp_ff;
extern compop_func op_5bd8_0_comp_ff;
extern compop_func op_5be0_0_comp_ff;
extern compop_func op_5be8_0_comp_ff;
extern compop_func op_5bf0_0_comp_ff;
extern compop_func op_5bf8_0_comp_ff;
extern compop_func op_5bf9_0_comp_ff;
extern compop_func op_5cc0_0_comp_ff;
extern compop_func op_5cc8_0_comp_ff;
extern compop_func op_5cd0_0_comp_ff;
extern compop_func op_5cd8_0_comp_ff;
extern compop_func op_5ce0_0_comp_ff;
extern compop_func op_5ce8_0_comp_ff;
extern compop_func op_5cf0_0_comp_ff;
extern compop_func op_5cf8_0_comp_ff;
extern compop_func op_5cf9_0_comp_ff;
extern compop_func op_5dc0_0_comp_ff;
extern compop_func op_5dc8_0_comp_ff;
extern compop_func op_5dd0_0_comp_ff;
extern compop_func op_5dd8_0_comp_ff;
extern compop_func op_5de0_0_comp_ff;
extern compop_func op_5de8_0_comp_ff;
extern compop_func op_5df0_0_comp_ff;
extern compop_func op_5df8_0_comp_ff;
extern compop_func op_5df9_0_comp_ff;
extern compop_func op_5ec0_0_comp_ff;
extern compop_func op_5ec8_0_comp_ff;
extern compop_func op_5ed0_0_comp_ff;
extern compop_func op_5ed8_0_comp_ff;
extern compop_func op_5ee0_0_comp_ff;
extern compop_func op_5ee8_0_comp_ff;
extern compop_func op_5ef0_0_comp_ff;
extern compop_func op_5ef8_0_comp_ff;
extern compop_func op_5ef9_0_comp_ff;
extern compop_func op_5fc0_0_comp_ff;
extern compop_func op_5fc8_0_comp_ff;
extern compop_func op_5fd0_0_comp_ff;
extern compop_func op_5fd8_0_comp_ff;
extern compop_func op_5fe0_0_comp_ff;
extern compop_func op_5fe8_0_comp_ff;
extern compop_func op_5ff0_0_comp_ff;
extern compop_func op_5ff8_0_comp_ff;
extern compop_func op_5ff9_0_comp_ff;
extern compop_func op_6000_0_comp_ff;
extern compop_func op_6001_0_comp_ff;
extern compop_func op_60ff_0_comp_ff;
extern compop_func op_6100_0_comp_ff;
extern compop_func op_6101_0_comp_ff;
extern compop_func op_61ff_0_comp_ff;
extern compop_func op_6200_0_comp_ff;
extern compop_func op_6201_0_comp_ff;
extern compop_func op_62ff_0_comp_ff;
extern compop_func op_6300_0_comp_ff;
extern compop_func op_6301_0_comp_ff;
extern compop_func op_63ff_0_comp_ff;
extern compop_func op_6400_0_comp_ff;
extern compop_func op_6401_0_comp_ff;
extern compop_func op_64ff_0_comp_ff;
extern compop_func op_6500_0_comp_ff;
extern compop_func op_6501_0_comp_ff;
extern compop_func op_65ff_0_comp_ff;
extern compop_func op_6600_0_comp_ff;
extern compop_func op_6601_0_comp_ff;
extern compop_func op_66ff_0_comp_ff;
extern compop_func op_6700_0_comp_ff;
extern compop_func op_6701_0_comp_ff;
extern compop_func op_67ff_0_comp_ff;
extern compop_func op_6a00_0_comp_ff;
extern compop_func op_6a01_0_comp_ff;
extern compop_func op_6aff_0_comp_ff;
extern compop_func op_6b00_0_comp_ff;
extern compop_func op_6b01_0_comp_ff;
extern compop_func op_6bff_0_comp_ff;
extern compop_func op_6c00_0_comp_ff;
extern compop_func op_6c01_0_comp_ff;
extern compop_func op_6cff_0_comp_ff;
extern compop_func op_6d00_0_comp_ff;
extern compop_func op_6d01_0_comp_ff;
extern compop_func op_6dff_0_comp_ff;
extern compop_func op_6e00_0_comp_ff;
extern compop_func op_6e01_0_comp_ff;
extern compop_func op_6eff_0_comp_ff;
extern compop_func op_6f00_0_comp_ff;
extern compop_func op_6f01_0_comp_ff;
extern compop_func op_6fff_0_comp_ff;
extern compop_func op_7000_0_comp_ff;
extern compop_func op_8000_0_comp_ff;
extern compop_func op_8010_0_comp_ff;
extern compop_func op_8018_0_comp_ff;
extern compop_func op_8020_0_comp_ff;
extern compop_func op_8028_0_comp_ff;
extern compop_func op_8030_0_comp_ff;
extern compop_func op_8038_0_comp_ff;
extern compop_func op_8039_0_comp_ff;
extern compop_func op_803a_0_comp_ff;
extern compop_func op_803b_0_comp_ff;
extern compop_func op_803c_0_comp_ff;
extern compop_func op_8040_0_comp_ff;
extern compop_func op_8050_0_comp_ff;
extern compop_func op_8058_0_comp_ff;
extern compop_func op_8060_0_comp_ff;
extern compop_func op_8068_0_comp_ff;
extern compop_func op_8070_0_comp_ff;
extern compop_func op_8078_0_comp_ff;
extern compop_func op_8079_0_comp_ff;
extern compop_func op_807a_0_comp_ff;
extern compop_func op_807b_0_comp_ff;
extern compop_func op_807c_0_comp_ff;
extern compop_func op_8080_0_comp_ff;
extern compop_func op_8090_0_comp_ff;
extern compop_func op_8098_0_comp_ff;
extern compop_func op_80a0_0_comp_ff;
extern compop_func op_80a8_0_comp_ff;
extern compop_func op_80b0_0_comp_ff;
extern compop_func op_80b8_0_comp_ff;
extern compop_func op_80b9_0_comp_ff;
extern compop_func op_80ba_0_comp_ff;
extern compop_func op_80bb_0_comp_ff;
extern compop_func op_80bc_0_comp_ff;
extern compop_func op_8110_0_comp_ff;
extern compop_func op_8118_0_comp_ff;
extern compop_func op_8120_0_comp_ff;
extern compop_func op_8128_0_comp_ff;
extern compop_func op_8130_0_comp_ff;
extern compop_func op_8138_0_comp_ff;
extern compop_func op_8139_0_comp_ff;
extern compop_func op_8150_0_comp_ff;
extern compop_func op_8158_0_comp_ff;
extern compop_func op_8160_0_comp_ff;
extern compop_func op_8168_0_comp_ff;
extern compop_func op_8170_0_comp_ff;
extern compop_func op_8178_0_comp_ff;
extern compop_func op_8179_0_comp_ff;
extern compop_func op_8190_0_comp_ff;
extern compop_func op_8198_0_comp_ff;
extern compop_func op_81a0_0_comp_ff;
extern compop_func op_81a8_0_comp_ff;
extern compop_func op_81b0_0_comp_ff;
extern compop_func op_81b8_0_comp_ff;
extern compop_func op_81b9_0_comp_ff;
extern compop_func op_9000_0_comp_ff;
extern compop_func op_9010_0_comp_ff;
extern compop_func op_9018_0_comp_ff;
extern compop_func op_9020_0_comp_ff;
extern compop_func op_9028_0_comp_ff;
extern compop_func op_9030_0_comp_ff;
extern compop_func op_9038_0_comp_ff;
extern compop_func op_9039_0_comp_ff;
extern compop_func op_903a_0_comp_ff;
extern compop_func op_903b_0_comp_ff;
extern compop_func op_903c_0_comp_ff;
extern compop_func op_9040_0_comp_ff;
extern compop_func op_9048_0_comp_ff;
extern compop_func op_9050_0_comp_ff;
extern compop_func op_9058_0_comp_ff;
extern compop_func op_9060_0_comp_ff;
extern compop_func op_9068_0_comp_ff;
extern compop_func op_9070_0_comp_ff;
extern compop_func op_9078_0_comp_ff;
extern compop_func op_9079_0_comp_ff;
extern compop_func op_907a_0_comp_ff;
extern compop_func op_907b_0_comp_ff;
extern compop_func op_907c_0_comp_ff;
extern compop_func op_9080_0_comp_ff;
extern compop_func op_9088_0_comp_ff;
extern compop_func op_9090_0_comp_ff;
extern compop_func op_9098_0_comp_ff;
extern compop_func op_90a0_0_comp_ff;
extern compop_func op_90a8_0_comp_ff;
extern compop_func op_90b0_0_comp_ff;
extern compop_func op_90b8_0_comp_ff;
extern compop_func op_90b9_0_comp_ff;
extern compop_func op_90ba_0_comp_ff;
extern compop_func op_90bb_0_comp_ff;
extern compop_func op_90bc_0_comp_ff;
extern compop_func op_90c0_0_comp_ff;
extern compop_func op_90c8_0_comp_ff;
extern compop_func op_90d0_0_comp_ff;
extern compop_func op_90d8_0_comp_ff;
extern compop_func op_90e0_0_comp_ff;
extern compop_func op_90e8_0_comp_ff;
extern compop_func op_90f0_0_comp_ff;
extern compop_func op_90f8_0_comp_ff;
extern compop_func op_90f9_0_comp_ff;
extern compop_func op_90fa_0_comp_ff;
extern compop_func op_90fb_0_comp_ff;
extern compop_func op_90fc_0_comp_ff;
extern compop_func op_9100_0_comp_ff;
extern compop_func op_9108_0_comp_ff;
extern compop_func op_9110_0_comp_ff;
extern compop_func op_9118_0_comp_ff;
extern compop_func op_9120_0_comp_ff;
extern compop_func op_9128_0_comp_ff;
extern compop_func op_9130_0_comp_ff;
extern compop_func op_9138_0_comp_ff;
extern compop_func op_9139_0_comp_ff;
extern compop_func op_9140_0_comp_ff;
extern compop_func op_9148_0_comp_ff;
extern compop_func op_9150_0_comp_ff;
extern compop_func op_9158_0_comp_ff;
extern compop_func op_9160_0_comp_ff;
extern compop_func op_9168_0_comp_ff;
extern compop_func op_9170_0_comp_ff;
extern compop_func op_9178_0_comp_ff;
extern compop_func op_9179_0_comp_ff;
extern compop_func op_9180_0_comp_ff;
extern compop_func op_9188_0_comp_ff;
extern compop_func op_9190_0_comp_ff;
extern compop_func op_9198_0_comp_ff;
extern compop_func op_91a0_0_comp_ff;
extern compop_func op_91a8_0_comp_ff;
extern compop_func op_91b0_0_comp_ff;
extern compop_func op_91b8_0_comp_ff;
extern compop_func op_91b9_0_comp_ff;
extern compop_func op_91c0_0_comp_ff;
extern compop_func op_91c8_0_comp_ff;
extern compop_func op_91d0_0_comp_ff;
extern compop_func op_91d8_0_comp_ff;
extern compop_func op_91e0_0_comp_ff;
extern compop_func op_91e8_0_comp_ff;
extern compop_func op_91f0_0_comp_ff;
extern compop_func op_91f8_0_comp_ff;
extern compop_func op_91f9_0_comp_ff;
extern compop_func op_91fa_0_comp_ff;
extern compop_func op_91fb_0_comp_ff;
extern compop_func op_91fc_0_comp_ff;
extern compop_func op_b000_0_comp_ff;
extern compop_func op_b010_0_comp_ff;
extern compop_func op_b018_0_comp_ff;
extern compop_func op_b020_0_comp_ff;
extern compop_func op_b028_0_comp_ff;
extern compop_func op_b030_0_comp_ff;
extern compop_func op_b038_0_comp_ff;
extern compop_func op_b039_0_comp_ff;
extern compop_func op_b03a_0_comp_ff;
extern compop_func op_b03b_0_comp_ff;
extern compop_func op_b03c_0_comp_ff;
extern compop_func op_b040_0_comp_ff;
extern compop_func op_b048_0_comp_ff;
extern compop_func op_b050_0_comp_ff;
extern compop_func op_b058_0_comp_ff;
extern compop_func op_b060_0_comp_ff;
extern compop_func op_b068_0_comp_ff;
extern compop_func op_b070_0_comp_ff;
extern compop_func op_b078_0_comp_ff;
extern compop_func op_b079_0_comp_ff;
extern compop_func op_b07a_0_comp_ff;
extern compop_func op_b07b_0_comp_ff;
extern compop_func op_b07c_0_comp_ff;
extern compop_func op_b080_0_comp_ff;
extern compop_func op_b088_0_comp_ff;
extern compop_func op_b090_0_comp_ff;
extern compop_func op_b098_0_comp_ff;
extern compop_func op_b0a0_0_comp_ff;
extern compop_func op_b0a8_0_comp_ff;
extern compop_func op_b0b0_0_comp_ff;
extern compop_func op_b0b8_0_comp_ff;
extern compop_func op_b0b9_0_comp_ff;
extern compop_func op_b0ba_0_comp_ff;
extern compop_func op_b0bb_0_comp_ff;
extern compop_func op_b0bc_0_comp_ff;
extern compop_func op_b0c0_0_comp_ff;
extern compop_func op_b0c8_0_comp_ff;
extern compop_func op_b0d0_0_comp_ff;
extern compop_func op_b0d8_0_comp_ff;
extern compop_func op_b0e0_0_comp_ff;
extern compop_func op_b0e8_0_comp_ff;
extern compop_func op_b0f0_0_comp_ff;
extern compop_func op_b0f8_0_comp_ff;
extern compop_func op_b0f9_0_comp_ff;
extern compop_func op_b0fa_0_comp_ff;
extern compop_func op_b0fb_0_comp_ff;
extern compop_func op_b0fc_0_comp_ff;
extern compop_func op_b100_0_comp_ff;
extern compop_func op_b108_0_comp_ff;
extern compop_func op_b110_0_comp_ff;
extern compop_func op_b118_0_comp_ff;
extern compop_func op_b120_0_comp_ff;
extern compop_func op_b128_0_comp_ff;
extern compop_func op_b130_0_comp_ff;
extern compop_func op_b138_0_comp_ff;
extern compop_func op_b139_0_comp_ff;
extern compop_func op_b140_0_comp_ff;
extern compop_func op_b148_0_comp_ff;
extern compop_func op_b150_0_comp_ff;
extern compop_func op_b158_0_comp_ff;
extern compop_func op_b160_0_comp_ff;
extern compop_func op_b168_0_comp_ff;
extern compop_func op_b170_0_comp_ff;
extern compop_func op_b178_0_comp_ff;
extern compop_func op_b179_0_comp_ff;
extern compop_func op_b180_0_comp_ff;
extern compop_func op_b188_0_comp_ff;
extern compop_func op_b190_0_comp_ff;
extern compop_func op_b198_0_comp_ff;
extern compop_func op_b1a0_0_comp_ff;
extern compop_func op_b1a8_0_comp_ff;
extern compop_func op_b1b0_0_comp_ff;
extern compop_func op_b1b8_0_comp_ff;
extern compop_func op_b1b9_0_comp_ff;
extern compop_func op_b1c0_0_comp_ff;
extern compop_func op_b1c8_0_comp_ff;
extern compop_func op_b1d0_0_comp_ff;
extern compop_func op_b1d8_0_comp_ff;
extern compop_func op_b1e0_0_comp_ff;
extern compop_func op_b1e8_0_comp_ff;
extern compop_func op_b1f0_0_comp_ff;
extern compop_func op_b1f8_0_comp_ff;
extern compop_func op_b1f9_0_comp_ff;
extern compop_func op_b1fa_0_comp_ff;
extern compop_func op_b1fb_0_comp_ff;
extern compop_func op_b1fc_0_comp_ff;
extern compop_func op_c000_0_comp_ff;
extern compop_func op_c010_0_comp_ff;
extern compop_func op_c018_0_comp_ff;
extern compop_func op_c020_0_comp_ff;
extern compop_func op_c028_0_comp_ff;
extern compop_func op_c030_0_comp_ff;
extern compop_func op_c038_0_comp_ff;
extern compop_func op_c039_0_comp_ff;
extern compop_func op_c03a_0_comp_ff;
extern compop_func op_c03b_0_comp_ff;
extern compop_func op_c03c_0_comp_ff;
extern compop_func op_c040_0_comp_ff;
extern compop_func op_c050_0_comp_ff;
extern compop_func op_c058_0_comp_ff;
extern compop_func op_c060_0_comp_ff;
extern compop_func op_c068_0_comp_ff;
extern compop_func op_c070_0_comp_ff;
extern compop_func op_c078_0_comp_ff;
extern compop_func op_c079_0_comp_ff;
extern compop_func op_c07a_0_comp_ff;
extern compop_func op_c07b_0_comp_ff;
extern compop_func op_c07c_0_comp_ff;
extern compop_func op_c080_0_comp_ff;
extern compop_func op_c090_0_comp_ff;
extern compop_func op_c098_0_comp_ff;
extern compop_func op_c0a0_0_comp_ff;
extern compop_func op_c0a8_0_comp_ff;
extern compop_func op_c0b0_0_comp_ff;
extern compop_func op_c0b8_0_comp_ff;
extern compop_func op_c0b9_0_comp_ff;
extern compop_func op_c0ba_0_comp_ff;
extern compop_func op_c0bb_0_comp_ff;
extern compop_func op_c0bc_0_comp_ff;
extern compop_func op_c0c0_0_comp_ff;
extern compop_func op_c0d0_0_comp_ff;
extern compop_func op_c0d8_0_comp_ff;
extern compop_func op_c0e0_0_comp_ff;
extern compop_func op_c0e8_0_comp_ff;
extern compop_func op_c0f0_0_comp_ff;
extern compop_func op_c0f8_0_comp_ff;
extern compop_func op_c0f9_0_comp_ff;
extern compop_func op_c0fa_0_comp_ff;
extern compop_func op_c0fb_0_comp_ff;
extern compop_func op_c0fc_0_comp_ff;
extern compop_func op_c110_0_comp_ff;
extern compop_func op_c118_0_comp_ff;
extern compop_func op_c120_0_comp_ff;
extern compop_func op_c128_0_comp_ff;
extern compop_func op_c130_0_comp_ff;
extern compop_func op_c138_0_comp_ff;
extern compop_func op_c139_0_comp_ff;
extern compop_func op_c140_0_comp_ff;
extern compop_func op_c148_0_comp_ff;
extern compop_func op_c150_0_comp_ff;
extern compop_func op_c158_0_comp_ff;
extern compop_func op_c160_0_comp_ff;
extern compop_func op_c168_0_comp_ff;
extern compop_func op_c170_0_comp_ff;
extern compop_func op_c178_0_comp_ff;
extern compop_func op_c179_0_comp_ff;
extern compop_func op_c188_0_comp_ff;
extern compop_func op_c190_0_comp_ff;
extern compop_func op_c198_0_comp_ff;
extern compop_func op_c1a0_0_comp_ff;
extern compop_func op_c1a8_0_comp_ff;
extern compop_func op_c1b0_0_comp_ff;
extern compop_func op_c1b8_0_comp_ff;
extern compop_func op_c1b9_0_comp_ff;
extern compop_func op_c1c0_0_comp_ff;
extern compop_func op_c1d0_0_comp_ff;
extern compop_func op_c1d8_0_comp_ff;
extern compop_func op_c1e0_0_comp_ff;
extern compop_func op_c1e8_0_comp_ff;
extern compop_func op_c1f0_0_comp_ff;
extern compop_func op_c1f8_0_comp_ff;
extern compop_func op_c1f9_0_comp_ff;
extern compop_func op_c1fa_0_comp_ff;
extern compop_func op_c1fb_0_comp_ff;
extern compop_func op_c1fc_0_comp_ff;
extern compop_func op_d000_0_comp_ff;
extern compop_func op_d010_0_comp_ff;
extern compop_func op_d018_0_comp_ff;
extern compop_func op_d020_0_comp_ff;
extern compop_func op_d028_0_comp_ff;
extern compop_func op_d030_0_comp_ff;
extern compop_func op_d038_0_comp_ff;
extern compop_func op_d039_0_comp_ff;
extern compop_func op_d03a_0_comp_ff;
extern compop_func op_d03b_0_comp_ff;
extern compop_func op_d03c_0_comp_ff;
extern compop_func op_d040_0_comp_ff;
extern compop_func op_d048_0_comp_ff;
extern compop_func op_d050_0_comp_ff;
extern compop_func op_d058_0_comp_ff;
extern compop_func op_d060_0_comp_ff;
extern compop_func op_d068_0_comp_ff;
extern compop_func op_d070_0_comp_ff;
extern compop_func op_d078_0_comp_ff;
extern compop_func op_d079_0_comp_ff;
extern compop_func op_d07a_0_comp_ff;
extern compop_func op_d07b_0_comp_ff;
extern compop_func op_d07c_0_comp_ff;
extern compop_func op_d080_0_comp_ff;
extern compop_func op_d088_0_comp_ff;
extern compop_func op_d090_0_comp_ff;
extern compop_func op_d098_0_comp_ff;
extern compop_func op_d0a0_0_comp_ff;
extern compop_func op_d0a8_0_comp_ff;
extern compop_func op_d0b0_0_comp_ff;
extern compop_func op_d0b8_0_comp_ff;
extern compop_func op_d0b9_0_comp_ff;
extern compop_func op_d0ba_0_comp_ff;
extern compop_func op_d0bb_0_comp_ff;
extern compop_func op_d0bc_0_comp_ff;
extern compop_func op_d0c0_0_comp_ff;
extern compop_func op_d0c8_0_comp_ff;
extern compop_func op_d0d0_0_comp_ff;
extern compop_func op_d0d8_0_comp_ff;
extern compop_func op_d0e0_0_comp_ff;
extern compop_func op_d0e8_0_comp_ff;
extern compop_func op_d0f0_0_comp_ff;
extern compop_func op_d0f8_0_comp_ff;
extern compop_func op_d0f9_0_comp_ff;
extern compop_func op_d0fa_0_comp_ff;
extern compop_func op_d0fb_0_comp_ff;
extern compop_func op_d0fc_0_comp_ff;
extern compop_func op_d100_0_comp_ff;
extern compop_func op_d108_0_comp_ff;
extern compop_func op_d110_0_comp_ff;
extern compop_func op_d118_0_comp_ff;
extern compop_func op_d120_0_comp_ff;
extern compop_func op_d128_0_comp_ff;
extern compop_func op_d130_0_comp_ff;
extern compop_func op_d138_0_comp_ff;
extern compop_func op_d139_0_comp_ff;
extern compop_func op_d140_0_comp_ff;
extern compop_func op_d148_0_comp_ff;
extern compop_func op_d150_0_comp_ff;
extern compop_func op_d158_0_comp_ff;
extern compop_func op_d160_0_comp_ff;
extern compop_func op_d168_0_comp_ff;
extern compop_func op_d170_0_comp_ff;
extern compop_func op_d178_0_comp_ff;
extern compop_func op_d179_0_comp_ff;
extern compop_func op_d180_0_comp_ff;
extern compop_func op_d188_0_comp_ff;
extern compop_func op_d190_0_comp_ff;
extern compop_func op_d198_0_comp_ff;
extern compop_func op_d1a0_0_comp_ff;
extern compop_func op_d1a8_0_comp_ff;
extern compop_func op_d1b0_0_comp_ff;
extern compop_func op_d1b8_0_comp_ff;
extern compop_func op_d1b9_0_comp_ff;
extern compop_func op_d1c0_0_comp_ff;
extern compop_func op_d1c8_0_comp_ff;
extern compop_func op_d1d0_0_comp_ff;
extern compop_func op_d1d8_0_comp_ff;
extern compop_func op_d1e0_0_comp_ff;
extern compop_func op_d1e8_0_comp_ff;
extern compop_func op_d1f0_0_comp_ff;
extern compop_func op_d1f8_0_comp_ff;
extern compop_func op_d1f9_0_comp_ff;
extern compop_func op_d1fa_0_comp_ff;
extern compop_func op_d1fb_0_comp_ff;
extern compop_func op_d1fc_0_comp_ff;
extern compop_func op_e000_0_comp_ff;
extern compop_func op_e008_0_comp_ff;
extern compop_func op_e018_0_comp_ff;
extern compop_func op_e020_0_comp_ff;
extern compop_func op_e028_0_comp_ff;
extern compop_func op_e038_0_comp_ff;
extern compop_func op_e040_0_comp_ff;
extern compop_func op_e048_0_comp_ff;
extern compop_func op_e058_0_comp_ff;
extern compop_func op_e060_0_comp_ff;
extern compop_func op_e068_0_comp_ff;
extern compop_func op_e078_0_comp_ff;
extern compop_func op_e080_0_comp_ff;
extern compop_func op_e088_0_comp_ff;
extern compop_func op_e098_0_comp_ff;
extern compop_func op_e0a0_0_comp_ff;
extern compop_func op_e0a8_0_comp_ff;
extern compop_func op_e0b8_0_comp_ff;
extern compop_func op_e0d0_0_comp_ff;
extern compop_func op_e0d8_0_comp_ff;
extern compop_func op_e0e0_0_comp_ff;
extern compop_func op_e0e8_0_comp_ff;
extern compop_func op_e0f0_0_comp_ff;
extern compop_func op_e0f8_0_comp_ff;
extern compop_func op_e0f9_0_comp_ff;
extern compop_func op_e100_0_comp_ff;
extern compop_func op_e108_0_comp_ff;
extern compop_func op_e118_0_comp_ff;
extern compop_func op_e120_0_comp_ff;
extern compop_func op_e128_0_comp_ff;
extern compop_func op_e138_0_comp_ff;
extern compop_func op_e140_0_comp_ff;
extern compop_func op_e148_0_comp_ff;
extern compop_func op_e158_0_comp_ff;
extern compop_func op_e160_0_comp_ff;
extern compop_func op_e168_0_comp_ff;
extern compop_func op_e178_0_comp_ff;
extern compop_func op_e180_0_comp_ff;
extern compop_func op_e188_0_comp_ff;
extern compop_func op_e198_0_comp_ff;
extern compop_func op_e1a0_0_comp_ff;
extern compop_func op_e1a8_0_comp_ff;
extern compop_func op_e1b8_0_comp_ff;
extern compop_func op_e1d0_0_comp_ff;
extern compop_func op_e1d8_0_comp_ff;
extern compop_func op_e1e0_0_comp_ff;
extern compop_func op_e1e8_0_comp_ff;
extern compop_func op_e1f0_0_comp_ff;
extern compop_func op_e1f8_0_comp_ff;
extern compop_func op_e1f9_0_comp_ff;
extern compop_func op_e2d0_0_comp_ff;
extern compop_func op_e2d8_0_comp_ff;
extern compop_func op_e2e0_0_comp_ff;
extern compop_func op_e2e8_0_comp_ff;
extern compop_func op_e2f0_0_comp_ff;
extern compop_func op_e2f8_0_comp_ff;
extern compop_func op_e2f9_0_comp_ff;
extern compop_func op_e3d0_0_comp_ff;
extern compop_func op_e3d8_0_comp_ff;
extern compop_func op_e3e0_0_comp_ff;
extern compop_func op_e3e8_0_comp_ff;
extern compop_func op_e3f0_0_comp_ff;
extern compop_func op_e3f8_0_comp_ff;
extern compop_func op_e3f9_0_comp_ff;
extern compop_func op_e6d0_0_comp_ff;
extern compop_func op_e6d8_0_comp_ff;
extern compop_func op_e6e0_0_comp_ff;
extern compop_func op_e6e8_0_comp_ff;
extern compop_func op_e6f0_0_comp_ff;
extern compop_func op_e6f8_0_comp_ff;
extern compop_func op_e6f9_0_comp_ff;
extern compop_func op_e7d0_0_comp_ff;
extern compop_func op_e7d8_0_comp_ff;
extern compop_func op_e7e0_0_comp_ff;
extern compop_func op_e7e8_0_comp_ff;
extern compop_func op_e7f0_0_comp_ff;
extern compop_func op_e7f8_0_comp_ff;
extern compop_func op_e7f9_0_comp_ff;
extern compop_func op_f600_0_comp_ff;
extern compop_func op_f608_0_comp_ff;
extern compop_func op_f610_0_comp_ff;
extern compop_func op_f618_0_comp_ff;
extern compop_func op_f620_0_comp_ff;
extern compop_func op_0_0_comp_nf;
extern compop_func op_10_0_comp_nf;
extern compop_func op_18_0_comp_nf;
extern compop_func op_20_0_comp_nf;
extern compop_func op_28_0_comp_nf;
extern compop_func op_30_0_comp_nf;
extern compop_func op_38_0_comp_nf;
extern compop_func op_39_0_comp_nf;
extern compop_func op_3c_0_comp_nf;
extern compop_func op_40_0_comp_nf;
extern compop_func op_50_0_comp_nf;
extern compop_func op_58_0_comp_nf;
extern compop_func op_60_0_comp_nf;
extern compop_func op_68_0_comp_nf;
extern compop_func op_70_0_comp_nf;
extern compop_func op_78_0_comp_nf;
extern compop_func op_79_0_comp_nf;
extern compop_func op_80_0_comp_nf;
extern compop_func op_90_0_comp_nf;
extern compop_func op_98_0_comp_nf;
extern compop_func op_a0_0_comp_nf;
extern compop_func op_a8_0_comp_nf;
extern compop_func op_b0_0_comp_nf;
extern compop_func op_b8_0_comp_nf;
extern compop_func op_b9_0_comp_nf;
extern compop_func op_100_0_comp_nf;
extern compop_func op_110_0_comp_nf;
extern compop_func op_118_0_comp_nf;
extern compop_func op_120_0_comp_nf;
extern compop_func op_128_0_comp_nf;
extern compop_func op_130_0_comp_nf;
extern compop_func op_138_0_comp_nf;
extern compop_func op_139_0_comp_nf;
extern compop_func op_13a_0_comp_nf;
extern compop_func op_13b_0_comp_nf;
extern compop_func op_13c_0_comp_nf;
extern compop_func op_140_0_comp_nf;
extern compop_func op_150_0_comp_nf;
extern compop_func op_158_0_comp_nf;
extern compop_func op_160_0_comp_nf;
extern compop_func op_168_0_comp_nf;
extern compop_func op_170_0_comp_nf;
extern compop_func op_178_0_comp_nf;
extern compop_func op_179_0_comp_nf;
extern compop_func op_180_0_comp_nf;
extern compop_func op_190_0_comp_nf;
extern compop_func op_198_0_comp_nf;
extern compop_func op_1a0_0_comp_nf;
extern compop_func op_1a8_0_comp_nf;
extern compop_func op_1b0_0_comp_nf;
extern compop_func op_1b8_0_comp_nf;
extern compop_func op_1b9_0_comp_nf;
extern compop_func op_1c0_0_comp_nf;
extern compop_func op_1d0_0_comp_nf;
extern compop_func op_1d8_0_comp_nf;
extern compop_func op_1e0_0_comp_nf;
extern compop_func op_1e8_0_comp_nf;
extern compop_func op_1f0_0_comp_nf;
extern compop_func op_1f8_0_comp_nf;
extern compop_func op_1f9_0_comp_nf;
extern compop_func op_200_0_comp_nf;
extern compop_func op_210_0_comp_nf;
extern compop_func op_218_0_comp_nf;
extern compop_func op_220_0_comp_nf;
extern compop_func op_228_0_comp_nf;
extern compop_func op_230_0_comp_nf;
extern compop_func op_238_0_comp_nf;
extern compop_func op_239_0_comp_nf;
extern compop_func op_23c_0_comp_nf;
extern compop_func op_240_0_comp_nf;
extern compop_func op_250_0_comp_nf;
extern compop_func op_258_0_comp_nf;
extern compop_func op_260_0_comp_nf;
extern compop_func op_268_0_comp_nf;
extern compop_func op_270_0_comp_nf;
extern compop_func op_278_0_comp_nf;
extern compop_func op_279_0_comp_nf;
extern compop_func op_280_0_comp_nf;
extern compop_func op_290_0_comp_nf;
extern compop_func op_298_0_comp_nf;
extern compop_func op_2a0_0_comp_nf;
extern compop_func op_2a8_0_comp_nf;
extern compop_func op_2b0_0_comp_nf;
extern compop_func op_2b8_0_comp_nf;
extern compop_func op_2b9_0_comp_nf;
extern compop_func op_400_0_comp_nf;
extern compop_func op_410_0_comp_nf;
extern compop_func op_418_0_comp_nf;
extern compop_func op_420_0_comp_nf;
extern compop_func op_428_0_comp_nf;
extern compop_func op_430_0_comp_nf;
extern compop_func op_438_0_comp_nf;
extern compop_func op_439_0_comp_nf;
extern compop_func op_440_0_comp_nf;
extern compop_func op_450_0_comp_nf;
extern compop_func op_458_0_comp_nf;
extern compop_func op_460_0_comp_nf;
extern compop_func op_468_0_comp_nf;
extern compop_func op_470_0_comp_nf;
extern compop_func op_478_0_comp_nf;
extern compop_func op_479_0_comp_nf;
extern compop_func op_480_0_comp_nf;
extern compop_func op_490_0_comp_nf;
extern compop_func op_498_0_comp_nf;
extern compop_func op_4a0_0_comp_nf;
extern compop_func op_4a8_0_comp_nf;
extern compop_func op_4b0_0_comp_nf;
extern compop_func op_4b8_0_comp_nf;
extern compop_func op_4b9_0_comp_nf;
extern compop_func op_600_0_comp_nf;
extern compop_func op_610_0_comp_nf;
extern compop_func op_618_0_comp_nf;
extern compop_func op_620_0_comp_nf;
extern compop_func op_628_0_comp_nf;
extern compop_func op_630_0_comp_nf;
extern compop_func op_638_0_comp_nf;
extern compop_func op_639_0_comp_nf;
extern compop_func op_640_0_comp_nf;
extern compop_func op_650_0_comp_nf;
extern compop_func op_658_0_comp_nf;
extern compop_func op_660_0_comp_nf;
extern compop_func op_668_0_comp_nf;
extern compop_func op_670_0_comp_nf;
extern compop_func op_678_0_comp_nf;
extern compop_func op_679_0_comp_nf;
extern compop_func op_680_0_comp_nf;
extern compop_func op_690_0_comp_nf;
extern compop_func op_698_0_comp_nf;
extern compop_func op_6a0_0_comp_nf;
extern compop_func op_6a8_0_comp_nf;
extern compop_func op_6b0_0_comp_nf;
extern compop_func op_6b8_0_comp_nf;
extern compop_func op_6b9_0_comp_nf;
extern compop_func op_800_0_comp_nf;
extern compop_func op_810_0_comp_nf;
extern compop_func op_818_0_comp_nf;
extern compop_func op_820_0_comp_nf;
extern compop_func op_828_0_comp_nf;
extern compop_func op_830_0_comp_nf;
extern compop_func op_838_0_comp_nf;
extern compop_func op_839_0_comp_nf;
extern compop_func op_83a_0_comp_nf;
extern compop_func op_83b_0_comp_nf;
extern compop_func op_840_0_comp_nf;
extern compop_func op_850_0_comp_nf;
extern compop_func op_858_0_comp_nf;
extern compop_func op_860_0_comp_nf;
extern compop_func op_868_0_comp_nf;
extern compop_func op_870_0_comp_nf;
extern compop_func op_878_0_comp_nf;
extern compop_func op_879_0_comp_nf;
extern compop_func op_880_0_comp_nf;
extern compop_func op_890_0_comp_nf;
extern compop_func op_898_0_comp_nf;
extern compop_func op_8a0_0_comp_nf;
extern compop_func op_8a8_0_comp_nf;
extern compop_func op_8b0_0_comp_nf;
extern compop_func op_8b8_0_comp_nf;
extern compop_func op_8b9_0_comp_nf;
extern compop_func op_8c0_0_comp_nf;
extern compop_func op_8d0_0_comp_nf;
extern compop_func op_8d8_0_comp_nf;
extern compop_func op_8e0_0_comp_nf;
extern compop_func op_8e8_0_comp_nf;
extern compop_func op_8f0_0_comp_nf;
extern compop_func op_8f8_0_comp_nf;
extern compop_func op_8f9_0_comp_nf;
extern compop_func op_a00_0_comp_nf;
extern compop_func op_a10_0_comp_nf;
extern compop_func op_a18_0_comp_nf;
extern compop_func op_a20_0_comp_nf;
extern compop_func op_a28_0_comp_nf;
extern compop_func op_a30_0_comp_nf;
extern compop_func op_a38_0_comp_nf;
extern compop_func op_a39_0_comp_nf;
extern compop_func op_a3c_0_comp_nf;
extern compop_func op_a40_0_comp_nf;
extern compop_func op_a50_0_comp_nf;
extern compop_func op_a58_0_comp_nf;
extern compop_func op_a60_0_comp_nf;
extern compop_func op_a68_0_comp_nf;
extern compop_func op_a70_0_comp_nf;
extern compop_func op_a78_0_comp_nf;
extern compop_func op_a79_0_comp_nf;
extern compop_func op_a80_0_comp_nf;
extern compop_func op_a90_0_comp_nf;
extern compop_func op_a98_0_comp_nf;
extern compop_func op_aa0_0_comp_nf;
extern compop_func op_aa8_0_comp_nf;
extern compop_func op_ab0_0_comp_nf;
extern compop_func op_ab8_0_comp_nf;
extern compop_func op_ab9_0_comp_nf;
extern compop_func op_c00_0_comp_nf;
extern compop_func op_c10_0_comp_nf;
extern compop_func op_c18_0_comp_nf;
extern compop_func op_c20_0_comp_nf;
extern compop_func op_c28_0_comp_nf;
extern compop_func op_c30_0_comp_nf;
extern compop_func op_c38_0_comp_nf;
extern compop_func op_c39_0_comp_nf;
extern compop_func op_c3a_0_comp_nf;
extern compop_func op_c3b_0_comp_nf;
extern compop_func op_c40_0_comp_nf;
extern compop_func op_c50_0_comp_nf;
extern compop_func op_c58_0_comp_nf;
extern compop_func op_c60_0_comp_nf;
extern compop_func op_c68_0_comp_nf;
extern compop_func op_c70_0_comp_nf;
extern compop_func op_c78_0_comp_nf;
extern compop_func op_c79_0_comp_nf;
extern compop_func op_c7a_0_comp_nf;
extern compop_func op_c7b_0_comp_nf;
extern compop_func op_c80_0_comp_nf;
extern compop_func op_c90_0_comp_nf;
extern compop_func op_c98_0_comp_nf;
extern compop_func op_ca0_0_comp_nf;
extern compop_func op_ca8_0_comp_nf;
extern compop_func op_cb0_0_comp_nf;
extern compop_func op_cb8_0_comp_nf;
extern compop_func op_cb9_0_comp_nf;
extern compop_func op_cba_0_comp_nf;
extern compop_func op_cbb_0_comp_nf;
extern compop_func op_1000_0_comp_nf;
extern compop_func op_1010_0_comp_nf;
extern compop_func op_1018_0_comp_nf;
extern compop_func op_1020_0_comp_nf;
extern compop_func op_1028_0_comp_nf;
extern compop_func op_1030_0_comp_nf;
extern compop_func op_1038_0_comp_nf;
extern compop_func op_1039_0_comp_nf;
extern compop_func op_103a_0_comp_nf;
extern compop_func op_103b_0_comp_nf;
extern compop_func op_103c_0_comp_nf;
extern compop_func op_1080_0_comp_nf;
extern compop_func op_1090_0_comp_nf;
extern compop_func op_1098_0_comp_nf;
extern compop_func op_10a0_0_comp_nf;
extern compop_func op_10a8_0_comp_nf;
extern compop_func op_10b0_0_comp_nf;
extern compop_func op_10b8_0_comp_nf;
extern compop_func op_10b9_0_comp_nf;
extern compop_func op_10ba_0_comp_nf;
extern compop_func op_10bb_0_comp_nf;
extern compop_func op_10bc_0_comp_nf;
extern compop_func op_10c0_0_comp_nf;
extern compop_func op_10d0_0_comp_nf;
extern compop_func op_10d8_0_comp_nf;
extern compop_func op_10e0_0_comp_nf;
extern compop_func op_10e8_0_comp_nf;
extern compop_func op_10f0_0_comp_nf;
extern compop_func op_10f8_0_comp_nf;
extern compop_func op_10f9_0_comp_nf;
extern compop_func op_10fa_0_comp_nf;
extern compop_func op_10fb_0_comp_nf;
extern compop_func op_10fc_0_comp_nf;
extern compop_func op_1100_0_comp_nf;
extern compop_func op_1110_0_comp_nf;
extern compop_func op_1118_0_comp_nf;
extern compop_func op_1120_0_comp_nf;
extern compop_func op_1128_0_comp_nf;
extern compop_func op_1130_0_comp_nf;
extern compop_func op_1138_0_comp_nf;
extern compop_func op_1139_0_comp_nf;
extern compop_func op_113a_0_comp_nf;
extern compop_func op_113b_0_comp_nf;
extern compop_func op_113c_0_comp_nf;
extern compop_func op_1140_0_comp_nf;
extern compop_func op_1150_0_comp_nf;
extern compop_func op_1158_0_comp_nf;
extern compop_func op_1160_0_comp_nf;
extern compop_func op_1168_0_comp_nf;
extern compop_func op_1170_0_comp_nf;
extern compop_func op_1178_0_comp_nf;
extern compop_func op_1179_0_comp_nf;
extern compop_func op_117a_0_comp_nf;
extern compop_func op_117b_0_comp_nf;
extern compop_func op_117c_0_comp_nf;
extern compop_func op_1180_0_comp_nf;
extern compop_func op_1190_0_comp_nf;
extern compop_func op_1198_0_comp_nf;
extern compop_func op_11a0_0_comp_nf;
extern compop_func op_11a8_0_comp_nf;
extern compop_func op_11b0_0_comp_nf;
extern compop_func op_11b8_0_comp_nf;
extern compop_func op_11b9_0_comp_nf;
extern compop_func op_11ba_0_comp_nf;
extern compop_func op_11bb_0_comp_nf;
extern compop_func op_11bc_0_comp_nf;
extern compop_func op_11c0_0_comp_nf;
extern compop_func op_11d0_0_comp_nf;
extern compop_func op_11d8_0_comp_nf;
extern compop_func op_11e0_0_comp_nf;
extern compop_func op_11e8_0_comp_nf;
extern compop_func op_11f0_0_comp_nf;
extern compop_func op_11f8_0_comp_nf;
extern compop_func op_11f9_0_comp_nf;
extern compop_func op_11fa_0_comp_nf;
extern compop_func op_11fb_0_comp_nf;
extern compop_func op_11fc_0_comp_nf;
extern compop_func op_13c0_0_comp_nf;
extern compop_func op_13d0_0_comp_nf;
extern compop_func op_13d8_0_comp_nf;
extern compop_func op_13e0_0_comp_nf;
extern compop_func op_13e8_0_comp_nf;
extern compop_func op_13f0_0_comp_nf;
extern compop_func op_13f8_0_comp_nf;
extern compop_func op_13f9_0_comp_nf;
extern compop_func op_13fa_0_comp_nf;
extern compop_func op_13fb_0_comp_nf;
extern compop_func op_13fc_0_comp_nf;
extern compop_func op_2000_0_comp_nf;
extern compop_func op_2008_0_comp_nf;
extern compop_func op_2010_0_comp_nf;
extern compop_func op_2018_0_comp_nf;
extern compop_func op_2020_0_comp_nf;
extern compop_func op_2028_0_comp_nf;
extern compop_func op_2030_0_comp_nf;
extern compop_func op_2038_0_comp_nf;
extern compop_func op_2039_0_comp_nf;
extern compop_func op_203a_0_comp_nf;
extern compop_func op_203b_0_comp_nf;
extern compop_func op_203c_0_comp_nf;
extern compop_func op_2040_0_comp_nf;
extern compop_func op_2048_0_comp_nf;
extern compop_func op_2050_0_comp_nf;
extern compop_func op_2058_0_comp_nf;
extern compop_func op_2060_0_comp_nf;
extern compop_func op_2068_0_comp_nf;
extern compop_func op_2070_0_comp_nf;
extern compop_func op_2078_0_comp_nf;
extern compop_func op_2079_0_comp_nf;
extern compop_func op_207a_0_comp_nf;
extern compop_func op_207b_0_comp_nf;
extern compop_func op_207c_0_comp_nf;
extern compop_func op_2080_0_comp_nf;
extern compop_func op_2088_0_comp_nf;
extern compop_func op_2090_0_comp_nf;
extern compop_func op_2098_0_comp_nf;
extern compop_func op_20a0_0_comp_nf;
extern compop_func op_20a8_0_comp_nf;
extern compop_func op_20b0_0_comp_nf;
extern compop_func op_20b8_0_comp_nf;
extern compop_func op_20b9_0_comp_nf;
extern compop_func op_20ba_0_comp_nf;
extern compop_func op_20bb_0_comp_nf;
extern compop_func op_20bc_0_comp_nf;
extern compop_func op_20c0_0_comp_nf;
extern compop_func op_20c8_0_comp_nf;
extern compop_func op_20d0_0_comp_nf;
extern compop_func op_20d8_0_comp_nf;
extern compop_func op_20e0_0_comp_nf;
extern compop_func op_20e8_0_comp_nf;
extern compop_func op_20f0_0_comp_nf;
extern compop_func op_20f8_0_comp_nf;
extern compop_func op_20f9_0_comp_nf;
extern compop_func op_20fa_0_comp_nf;
extern compop_func op_20fb_0_comp_nf;
extern compop_func op_20fc_0_comp_nf;
extern compop_func op_2100_0_comp_nf;
extern compop_func op_2108_0_comp_nf;
extern compop_func op_2110_0_comp_nf;
extern compop_func op_2118_0_comp_nf;
extern compop_func op_2120_0_comp_nf;
extern compop_func op_2128_0_comp_nf;
extern compop_func op_2130_0_comp_nf;
extern compop_func op_2138_0_comp_nf;
extern compop_func op_2139_0_comp_nf;
extern compop_func op_213a_0_comp_nf;
extern compop_func op_213b_0_comp_nf;
extern compop_func op_213c_0_comp_nf;
extern compop_func op_2140_0_comp_nf;
extern compop_func op_2148_0_comp_nf;
extern compop_func op_2150_0_comp_nf;
extern compop_func op_2158_0_comp_nf;
extern compop_func op_2160_0_comp_nf;
extern compop_func op_2168_0_comp_nf;
extern compop_func op_2170_0_comp_nf;
extern compop_func op_2178_0_comp_nf;
extern compop_func op_2179_0_comp_nf;
extern compop_func op_217a_0_comp_nf;
extern compop_func op_217b_0_comp_nf;
extern compop_func op_217c_0_comp_nf;
extern compop_func op_2180_0_comp_nf;
extern compop_func op_2188_0_comp_nf;
extern compop_func op_2190_0_comp_nf;
extern compop_func op_2198_0_comp_nf;
extern compop_func op_21a0_0_comp_nf;
extern compop_func op_21a8_0_comp_nf;
extern compop_func op_21b0_0_comp_nf;
extern compop_func op_21b8_0_comp_nf;
extern compop_func op_21b9_0_comp_nf;
extern compop_func op_21ba_0_comp_nf;
extern compop_func op_21bb_0_comp_nf;
extern compop_func op_21bc_0_comp_nf;
extern compop_func op_21c0_0_comp_nf;
extern compop_func op_21c8_0_comp_nf;
extern compop_func op_21d0_0_comp_nf;
extern compop_func op_21d8_0_comp_nf;
extern compop_func op_21e0_0_comp_nf;
extern compop_func op_21e8_0_comp_nf;
extern compop_func op_21f0_0_comp_nf;
extern compop_func op_21f8_0_comp_nf;
extern compop_func op_21f9_0_comp_nf;
extern compop_func op_21fa_0_comp_nf;
extern compop_func op_21fb_0_comp_nf;
extern compop_func op_21fc_0_comp_nf;
extern compop_func op_23c0_0_comp_nf;
extern compop_func op_23c8_0_comp_nf;
extern compop_func op_23d0_0_comp_nf;
extern compop_func op_23d8_0_comp_nf;
extern compop_func op_23e0_0_comp_nf;
extern compop_func op_23e8_0_comp_nf;
extern compop_func op_23f0_0_comp_nf;
extern compop_func op_23f8_0_comp_nf;
extern compop_func op_23f9_0_comp_nf;
extern compop_func op_23fa_0_comp_nf;
extern compop_func op_23fb_0_comp_nf;
extern compop_func op_23fc_0_comp_nf;
extern compop_func op_3000_0_comp_nf;
extern compop_func op_3008_0_comp_nf;
extern compop_func op_3010_0_comp_nf;
extern compop_func op_3018_0_comp_nf;
extern compop_func op_3020_0_comp_nf;
extern compop_func op_3028_0_comp_nf;
extern compop_func op_3030_0_comp_nf;
extern compop_func op_3038_0_comp_nf;
extern compop_func op_3039_0_comp_nf;
extern compop_func op_303a_0_comp_nf;
extern compop_func op_303b_0_comp_nf;
extern compop_func op_303c_0_comp_nf;
extern compop_func op_3040_0_comp_nf;
extern compop_func op_3048_0_comp_nf;
extern compop_func op_3050_0_comp_nf;
extern compop_func op_3058_0_comp_nf;
extern compop_func op_3060_0_comp_nf;
extern compop_func op_3068_0_comp_nf;
extern compop_func op_3070_0_comp_nf;
extern compop_func op_3078_0_comp_nf;
extern compop_func op_3079_0_comp_nf;
extern compop_func op_307a_0_comp_nf;
extern compop_func op_307b_0_comp_nf;
extern compop_func op_307c_0_comp_nf;
extern compop_func op_3080_0_comp_nf;
extern compop_func op_3088_0_comp_nf;
extern compop_func op_3090_0_comp_nf;
extern compop_func op_3098_0_comp_nf;
extern compop_func op_30a0_0_comp_nf;
extern compop_func op_30a8_0_comp_nf;
extern compop_func op_30b0_0_comp_nf;
extern compop_func op_30b8_0_comp_nf;
extern compop_func op_30b9_0_comp_nf;
extern compop_func op_30ba_0_comp_nf;
extern compop_func op_30bb_0_comp_nf;
extern compop_func op_30bc_0_comp_nf;
extern compop_func op_30c0_0_comp_nf;
extern compop_func op_30c8_0_comp_nf;
extern compop_func op_30d0_0_comp_nf;
extern compop_func op_30d8_0_comp_nf;
extern compop_func op_30e0_0_comp_nf;
extern compop_func op_30e8_0_comp_nf;
extern compop_func op_30f0_0_comp_nf;
extern compop_func op_30f8_0_comp_nf;
extern compop_func op_30f9_0_comp_nf;
extern compop_func op_30fa_0_comp_nf;
extern compop_func op_30fb_0_comp_nf;
extern compop_func op_30fc_0_comp_nf;
extern compop_func op_3100_0_comp_nf;
extern compop_func op_3108_0_comp_nf;
extern compop_func op_3110_0_comp_nf;
extern compop_func op_3118_0_comp_nf;
extern compop_func op_3120_0_comp_nf;
extern compop_func op_3128_0_comp_nf;
extern compop_func op_3130_0_comp_nf;
extern compop_func op_3138_0_comp_nf;
extern compop_func op_3139_0_comp_nf;
extern compop_func op_313a_0_comp_nf;
extern compop_func op_313b_0_comp_nf;
extern compop_func op_313c_0_comp_nf;
extern compop_func op_3140_0_comp_nf;
extern compop_func op_3148_0_comp_nf;
extern compop_func op_3150_0_comp_nf;
extern compop_func op_3158_0_comp_nf;
extern compop_func op_3160_0_comp_nf;
extern compop_func op_3168_0_comp_nf;
extern compop_func op_3170_0_comp_nf;
extern compop_func op_3178_0_comp_nf;
extern compop_func op_3179_0_comp_nf;
extern compop_func op_317a_0_comp_nf;
extern compop_func op_317b_0_comp_nf;
extern compop_func op_317c_0_comp_nf;
extern compop_func op_3180_0_comp_nf;
extern compop_func op_3188_0_comp_nf;
extern compop_func op_3190_0_comp_nf;
extern compop_func op_3198_0_comp_nf;
extern compop_func op_31a0_0_comp_nf;
extern compop_func op_31a8_0_comp_nf;
extern compop_func op_31b0_0_comp_nf;
extern compop_func op_31b8_0_comp_nf;
extern compop_func op_31b9_0_comp_nf;
extern compop_func op_31ba_0_comp_nf;
extern compop_func op_31bb_0_comp_nf;
extern compop_func op_31bc_0_comp_nf;
extern compop_func op_31c0_0_comp_nf;
extern compop_func op_31c8_0_comp_nf;
extern compop_func op_31d0_0_comp_nf;
extern compop_func op_31d8_0_comp_nf;
extern compop_func op_31e0_0_comp_nf;
extern compop_func op_31e8_0_comp_nf;
extern compop_func op_31f0_0_comp_nf;
extern compop_func op_31f8_0_comp_nf;
extern compop_func op_31f9_0_comp_nf;
extern compop_func op_31fa_0_comp_nf;
extern compop_func op_31fb_0_comp_nf;
extern compop_func op_31fc_0_comp_nf;
extern compop_func op_33c0_0_comp_nf;
extern compop_func op_33c8_0_comp_nf;
extern compop_func op_33d0_0_comp_nf;
extern compop_func op_33d8_0_comp_nf;
extern compop_func op_33e0_0_comp_nf;
extern compop_func op_33e8_0_comp_nf;
extern compop_func op_33f0_0_comp_nf;
extern compop_func op_33f8_0_comp_nf;
extern compop_func op_33f9_0_comp_nf;
extern compop_func op_33fa_0_comp_nf;
extern compop_func op_33fb_0_comp_nf;
extern compop_func op_33fc_0_comp_nf;
extern compop_func op_4000_0_comp_nf;
extern compop_func op_4010_0_comp_nf;
extern compop_func op_4018_0_comp_nf;
extern compop_func op_4020_0_comp_nf;
extern compop_func op_4028_0_comp_nf;
extern compop_func op_4030_0_comp_nf;
extern compop_func op_4038_0_comp_nf;
extern compop_func op_4039_0_comp_nf;
extern compop_func op_4040_0_comp_nf;
extern compop_func op_4050_0_comp_nf;
extern compop_func op_4058_0_comp_nf;
extern compop_func op_4060_0_comp_nf;
extern compop_func op_4068_0_comp_nf;
extern compop_func op_4070_0_comp_nf;
extern compop_func op_4078_0_comp_nf;
extern compop_func op_4079_0_comp_nf;
extern compop_func op_4080_0_comp_nf;
extern compop_func op_4090_0_comp_nf;
extern compop_func op_4098_0_comp_nf;
extern compop_func op_40a0_0_comp_nf;
extern compop_func op_40a8_0_comp_nf;
extern compop_func op_40b0_0_comp_nf;
extern compop_func op_40b8_0_comp_nf;
extern compop_func op_40b9_0_comp_nf;
extern compop_func op_41d0_0_comp_nf;
extern compop_func op_41e8_0_comp_nf;
extern compop_func op_41f0_0_comp_nf;
extern compop_func op_41f8_0_comp_nf;
extern compop_func op_41f9_0_comp_nf;
extern compop_func op_41fa_0_comp_nf;
extern compop_func op_41fb_0_comp_nf;
extern compop_func op_4200_0_comp_nf;
extern compop_func op_4210_0_comp_nf;
extern compop_func op_4218_0_comp_nf;
extern compop_func op_4220_0_comp_nf;
extern compop_func op_4228_0_comp_nf;
extern compop_func op_4230_0_comp_nf;
extern compop_func op_4238_0_comp_nf;
extern compop_func op_4239_0_comp_nf;
extern compop_func op_4240_0_comp_nf;
extern compop_func op_4250_0_comp_nf;
extern compop_func op_4258_0_comp_nf;
extern compop_func op_4260_0_comp_nf;
extern compop_func op_4268_0_comp_nf;
extern compop_func op_4270_0_comp_nf;
extern compop_func op_4278_0_comp_nf;
extern compop_func op_4279_0_comp_nf;
extern compop_func op_4280_0_comp_nf;
extern compop_func op_4290_0_comp_nf;
extern compop_func op_4298_0_comp_nf;
extern compop_func op_42a0_0_comp_nf;
extern compop_func op_42a8_0_comp_nf;
extern compop_func op_42b0_0_comp_nf;
extern compop_func op_42b8_0_comp_nf;
extern compop_func op_42b9_0_comp_nf;
extern compop_func op_4400_0_comp_nf;
extern compop_func op_4410_0_comp_nf;
extern compop_func op_4418_0_comp_nf;
extern compop_func op_4420_0_comp_nf;
extern compop_func op_4428_0_comp_nf;
extern compop_func op_4430_0_comp_nf;
extern compop_func op_4438_0_comp_nf;
extern compop_func op_4439_0_comp_nf;
extern compop_func op_4440_0_comp_nf;
extern compop_func op_4450_0_comp_nf;
extern compop_func op_4458_0_comp_nf;
extern compop_func op_4460_0_comp_nf;
extern compop_func op_4468_0_comp_nf;
extern compop_func op_4470_0_comp_nf;
extern compop_func op_4478_0_comp_nf;
extern compop_func op_4479_0_comp_nf;
extern compop_func op_4480_0_comp_nf;
extern compop_func op_4490_0_comp_nf;
extern compop_func op_4498_0_comp_nf;
extern compop_func op_44a0_0_comp_nf;
extern compop_func op_44a8_0_comp_nf;
extern compop_func op_44b0_0_comp_nf;
extern compop_func op_44b8_0_comp_nf;
extern compop_func op_44b9_0_comp_nf;
extern compop_func op_4600_0_comp_nf;
extern compop_func op_4610_0_comp_nf;
extern compop_func op_4618_0_comp_nf;
extern compop_func op_4620_0_comp_nf;
extern compop_func op_4628_0_comp_nf;
extern compop_func op_4630_0_comp_nf;
extern compop_func op_4638_0_comp_nf;
extern compop_func op_4639_0_comp_nf;
extern compop_func op_4640_0_comp_nf;
extern compop_func op_4650_0_comp_nf;
extern compop_func op_4658_0_comp_nf;
extern compop_func op_4660_0_comp_nf;
extern compop_func op_4668_0_comp_nf;
extern compop_func op_4670_0_comp_nf;
extern compop_func op_4678_0_comp_nf;
extern compop_func op_4679_0_comp_nf;
extern compop_func op_4680_0_comp_nf;
extern compop_func op_4690_0_comp_nf;
extern compop_func op_4698_0_comp_nf;
extern compop_func op_46a0_0_comp_nf;
extern compop_func op_46a8_0_comp_nf;
extern compop_func op_46b0_0_comp_nf;
extern compop_func op_46b8_0_comp_nf;
extern compop_func op_46b9_0_comp_nf;
extern compop_func op_4808_0_comp_nf;
extern compop_func op_4840_0_comp_nf;
extern compop_func op_4850_0_comp_nf;
extern compop_func op_4868_0_comp_nf;
extern compop_func op_4870_0_comp_nf;
extern compop_func op_4878_0_comp_nf;
extern compop_func op_4879_0_comp_nf;
extern compop_func op_487a_0_comp_nf;
extern compop_func op_487b_0_comp_nf;
extern compop_func op_4880_0_comp_nf;
extern compop_func op_4890_0_comp_nf;
extern compop_func op_48a0_0_comp_nf;
extern compop_func op_48a8_0_comp_nf;
extern compop_func op_48b0_0_comp_nf;
extern compop_func op_48b8_0_comp_nf;
extern compop_func op_48b9_0_comp_nf;
extern compop_func op_48c0_0_comp_nf;
extern compop_func op_48d0_0_comp_nf;
extern compop_func op_48e0_0_comp_nf;
extern compop_func op_48e8_0_comp_nf;
extern compop_func op_48f0_0_comp_nf;
extern compop_func op_48f8_0_comp_nf;
extern compop_func op_48f9_0_comp_nf;
extern compop_func op_49c0_0_comp_nf;
extern compop_func op_4a00_0_comp_nf;
extern compop_func op_4a10_0_comp_nf;
extern compop_func op_4a18_0_comp_nf;
extern compop_func op_4a20_0_comp_nf;
extern compop_func op_4a28_0_comp_nf;
extern compop_func op_4a30_0_comp_nf;
extern compop_func op_4a38_0_comp_nf;
extern compop_func op_4a39_0_comp_nf;
extern compop_func op_4a3a_0_comp_nf;
extern compop_func op_4a3b_0_comp_nf;
extern compop_func op_4a40_0_comp_nf;
extern compop_func op_4a48_0_comp_nf;
extern compop_func op_4a50_0_comp_nf;
extern compop_func op_4a58_0_comp_nf;
extern compop_func op_4a60_0_comp_nf;
extern compop_func op_4a68_0_comp_nf;
extern compop_func op_4a70_0_comp_nf;
extern compop_func op_4a78_0_comp_nf;
extern compop_func op_4a79_0_comp_nf;
extern compop_func op_4a7a_0_comp_nf;
extern compop_func op_4a7b_0_comp_nf;
extern compop_func op_4a80_0_comp_nf;
extern compop_func op_4a88_0_comp_nf;
extern compop_func op_4a90_0_comp_nf;
extern compop_func op_4a98_0_comp_nf;
extern compop_func op_4aa0_0_comp_nf;
extern compop_func op_4aa8_0_comp_nf;
extern compop_func op_4ab0_0_comp_nf;
extern compop_func op_4ab8_0_comp_nf;
extern compop_func op_4ab9_0_comp_nf;
extern compop_func op_4aba_0_comp_nf;
extern compop_func op_4abb_0_comp_nf;
extern compop_func op_4c00_0_comp_nf;
extern compop_func op_4c10_0_comp_nf;
extern compop_func op_4c18_0_comp_nf;
extern compop_func op_4c20_0_comp_nf;
extern compop_func op_4c28_0_comp_nf;
extern compop_func op_4c30_0_comp_nf;
extern compop_func op_4c38_0_comp_nf;
extern compop_func op_4c39_0_comp_nf;
extern compop_func op_4c3a_0_comp_nf;
extern compop_func op_4c3b_0_comp_nf;
extern compop_func op_4c3c_0_comp_nf;
extern compop_func op_4c90_0_comp_nf;
extern compop_func op_4c98_0_comp_nf;
extern compop_func op_4ca8_0_comp_nf;
extern compop_func op_4cb0_0_comp_nf;
extern compop_func op_4cb8_0_comp_nf;
extern compop_func op_4cb9_0_comp_nf;
extern compop_func op_4cba_0_comp_nf;
extern compop_func op_4cbb_0_comp_nf;
extern compop_func op_4cd0_0_comp_nf;
extern compop_func op_4cd8_0_comp_nf;
extern compop_func op_4ce8_0_comp_nf;
extern compop_func op_4cf0_0_comp_nf;
extern compop_func op_4cf8_0_comp_nf;
extern compop_func op_4cf9_0_comp_nf;
extern compop_func op_4cfa_0_comp_nf;
extern compop_func op_4cfb_0_comp_nf;
extern compop_func op_4e50_0_comp_nf;
extern compop_func op_4e58_0_comp_nf;
extern compop_func op_4e71_0_comp_nf;
extern compop_func op_4e74_0_comp_nf;
extern compop_func op_4e75_0_comp_nf;
extern compop_func op_4e90_0_comp_nf;
extern compop_func op_4ea8_0_comp_nf;
extern compop_func op_4eb0_0_comp_nf;
extern compop_func op_4eb8_0_comp_nf;
extern compop_func op_4eb9_0_comp_nf;
extern compop_func op_4eba_0_comp_nf;
extern compop_func op_4ebb_0_comp_nf;
extern compop_func op_4ed0_0_comp_nf;
extern compop_func op_4ee8_0_comp_nf;
extern compop_func op_4ef0_0_comp_nf;
extern compop_func op_4ef8_0_comp_nf;
extern compop_func op_4ef9_0_comp_nf;
extern compop_func op_4efa_0_comp_nf;
extern compop_func op_4efb_0_comp_nf;
extern compop_func op_5000_0_comp_nf;
extern compop_func op_5010_0_comp_nf;
extern compop_func op_5018_0_comp_nf;
extern compop_func op_5020_0_comp_nf;
extern compop_func op_5028_0_comp_nf;
extern compop_func op_5030_0_comp_nf;
extern compop_func op_5038_0_comp_nf;
extern compop_func op_5039_0_comp_nf;
extern compop_func op_5040_0_comp_nf;
extern compop_func op_5048_0_comp_nf;
extern compop_func op_5050_0_comp_nf;
extern compop_func op_5058_0_comp_nf;
extern compop_func op_5060_0_comp_nf;
extern compop_func op_5068_0_comp_nf;
extern compop_func op_5070_0_comp_nf;
extern compop_func op_5078_0_comp_nf;
extern compop_func op_5079_0_comp_nf;
extern compop_func op_5080_0_comp_nf;
extern compop_func op_5088_0_comp_nf;
extern compop_func op_5090_0_comp_nf;
extern compop_func op_5098_0_comp_nf;
extern compop_func op_50a0_0_comp_nf;
extern compop_func op_50a8_0_comp_nf;
extern compop_func op_50b0_0_comp_nf;
extern compop_func op_50b8_0_comp_nf;
extern compop_func op_50b9_0_comp_nf;
extern compop_func op_50c0_0_comp_nf;
extern compop_func op_50c8_0_comp_nf;
extern compop_func op_50d0_0_comp_nf;
extern compop_func op_50d8_0_comp_nf;
extern compop_func op_50e0_0_comp_nf;
extern compop_func op_50e8_0_comp_nf;
extern compop_func op_50f0_0_comp_nf;
extern compop_func op_50f8_0_comp_nf;
extern compop_func op_50f9_0_comp_nf;
extern compop_func op_5100_0_comp_nf;
extern compop_func op_5110_0_comp_nf;
extern compop_func op_5118_0_comp_nf;
extern compop_func op_5120_0_comp_nf;
extern compop_func op_5128_0_comp_nf;
extern compop_func op_5130_0_comp_nf;
extern compop_func op_5138_0_comp_nf;
extern compop_func op_5139_0_comp_nf;
extern compop_func op_5140_0_comp_nf;
extern compop_func op_5148_0_comp_nf;
extern compop_func op_5150_0_comp_nf;
extern compop_func op_5158_0_comp_nf;
extern compop_func op_5160_0_comp_nf;
extern compop_func op_5168_0_comp_nf;
extern compop_func op_5170_0_comp_nf;
extern compop_func op_5178_0_comp_nf;
extern compop_func op_5179_0_comp_nf;
extern compop_func op_5180_0_comp_nf;
extern compop_func op_5188_0_comp_nf;
extern compop_func op_5190_0_comp_nf;
extern compop_func op_5198_0_comp_nf;
extern compop_func op_51a0_0_comp_nf;
extern compop_func op_51a8_0_comp_nf;
extern compop_func op_51b0_0_comp_nf;
extern compop_func op_51b8_0_comp_nf;
extern compop_func op_51b9_0_comp_nf;
extern compop_func op_51c0_0_comp_nf;
extern compop_func op_51c8_0_comp_nf;
extern compop_func op_51d0_0_comp_nf;
extern compop_func op_51d8_0_comp_nf;
extern compop_func op_51e0_0_comp_nf;
extern compop_func op_51e8_0_comp_nf;
extern compop_func op_51f0_0_comp_nf;
extern compop_func op_51f8_0_comp_nf;
extern compop_func op_51f9_0_comp_nf;
extern compop_func op_52c0_0_comp_nf;
extern compop_func op_52c8_0_comp_nf;
extern compop_func op_52d0_0_comp_nf;
extern compop_func op_52d8_0_comp_nf;
extern compop_func op_52e0_0_comp_nf;
extern compop_func op_52e8_0_comp_nf;
extern compop_func op_52f0_0_comp_nf;
extern compop_func op_52f8_0_comp_nf;
extern compop_func op_52f9_0_comp_nf;
extern compop_func op_53c0_0_comp_nf;
extern compop_func op_53c8_0_comp_nf;
extern compop_func op_53d0_0_comp_nf;
extern compop_func op_53d8_0_comp_nf;
extern compop_func op_53e0_0_comp_nf;
extern compop_func op_53e8_0_comp_nf;
extern compop_func op_53f0_0_comp_nf;
extern compop_func op_53f8_0_comp_nf;
extern compop_func op_53f9_0_comp_nf;
extern compop_func op_54c0_0_comp_nf;
extern compop_func op_54c8_0_comp_nf;
extern compop_func op_54d0_0_comp_nf;
extern compop_func op_54d8_0_comp_nf;
extern compop_func op_54e0_0_comp_nf;
extern compop_func op_54e8_0_comp_nf;
extern compop_func op_54f0_0_comp_nf;
extern compop_func op_54f8_0_comp_nf;
extern compop_func op_54f9_0_comp_nf;
extern compop_func op_55c0_0_comp_nf;
extern compop_func op_55c8_0_comp_nf;
extern compop_func op_55d0_0_comp_nf;
extern compop_func op_55d8_0_comp_nf;
extern compop_func op_55e0_0_comp_nf;
extern compop_func op_55e8_0_comp_nf;
extern compop_func op_55f0_0_comp_nf;
extern compop_func op_55f8_0_comp_nf;
extern compop_func op_55f9_0_comp_nf;
extern compop_func op_56c0_0_comp_nf;
extern compop_func op_56c8_0_comp_nf;
extern compop_func op_56d0_0_comp_nf;
extern compop_func op_56d8_0_comp_nf;
extern compop_func op_56e0_0_comp_nf;
extern compop_func op_56e8_0_comp_nf;
extern compop_func op_56f0_0_comp_nf;
extern compop_func op_56f8_0_comp_nf;
extern compop_func op_56f9_0_comp_nf;
extern compop_func op_57c0_0_comp_nf;
extern compop_func op_57c8_0_comp_nf;
extern compop_func op_57d0_0_comp_nf;
extern compop_func op_57d8_0_comp_nf;
extern compop_func op_57e0_0_comp_nf;
extern compop_func op_57e8_0_comp_nf;
extern compop_func op_57f0_0_comp_nf;
extern compop_func op_57f8_0_comp_nf;
extern compop_func op_57f9_0_comp_nf;
extern compop_func op_58c0_0_comp_nf;
extern compop_func op_58c8_0_comp_nf;
extern compop_func op_58d0_0_comp_nf;
extern compop_func op_58d8_0_comp_nf;
extern compop_func op_58e0_0_comp_nf;
extern compop_func op_58e8_0_comp_nf;
extern compop_func op_58f0_0_comp_nf;
extern compop_func op_58f8_0_comp_nf;
extern compop_func op_58f9_0_comp_nf;
extern compop_func op_59c0_0_comp_nf;
extern compop_func op_59c8_0_comp_nf;
extern compop_func op_59d0_0_comp_nf;
extern compop_func op_59d8_0_comp_nf;
extern compop_func op_59e0_0_comp_nf;
extern compop_func op_59e8_0_comp_nf;
extern compop_func op_59f0_0_comp_nf;
extern compop_func op_59f8_0_comp_nf;
extern compop_func op_59f9_0_comp_nf;
extern compop_func op_5ac0_0_comp_nf;
extern compop_func op_5ac8_0_comp_nf;
extern compop_func op_5ad0_0_comp_nf;
extern compop_func op_5ad8_0_comp_nf;
extern compop_func op_5ae0_0_comp_nf;
extern compop_func op_5ae8_0_comp_nf;
extern compop_func op_5af0_0_comp_nf;
extern compop_func op_5af8_0_comp_nf;
extern compop_func op_5af9_0_comp_nf;
extern compop_func op_5bc0_0_comp_nf;
extern compop_func op_5bc8_0_comp_nf;
extern compop_func op_5bd0_0_comp_nf;
extern compop_func op_5bd8_0_comp_nf;
extern compop_func op_5be0_0_comp_nf;
extern compop_func op_5be8_0_comp_nf;
extern compop_func op_5bf0_0_comp_nf;
extern compop_func op_5bf8_0_comp_nf;
extern compop_func op_5bf9_0_comp_nf;
extern compop_func op_5cc0_0_comp_nf;
extern compop_func op_5cc8_0_comp_nf;
extern compop_func op_5cd0_0_comp_nf;
extern compop_func op_5cd8_0_comp_nf;
extern compop_func op_5ce0_0_comp_nf;
extern compop_func op_5ce8_0_comp_nf;
extern compop_func op_5cf0_0_comp_nf;
extern compop_func op_5cf8_0_comp_nf;
extern compop_func op_5cf9_0_comp_nf;
extern compop_func op_5dc0_0_comp_nf;
extern compop_func op_5dc8_0_comp_nf;
extern compop_func op_5dd0_0_comp_nf;
extern compop_func op_5dd8_0_comp_nf;
extern compop_func op_5de0_0_comp_nf;
extern compop_func op_5de8_0_comp_nf;
extern compop_func op_5df0_0_comp_nf;
extern compop_func op_5df8_0_comp_nf;
extern compop_func op_5df9_0_comp_nf;
extern compop_func op_5ec0_0_comp_nf;
extern compop_func op_5ec8_0_comp_nf;
extern compop_func op_5ed0_0_comp_nf;
extern compop_func op_5ed8_0_comp_nf;
extern compop_func op_5ee0_0_comp_nf;
extern compop_func op_5ee8_0_comp_nf;
extern compop_func op_5ef0_0_comp_nf;
extern compop_func op_5ef8_0_comp_nf;
extern compop_func op_5ef9_0_comp_nf;
extern compop_func op_5fc0_0_comp_nf;
extern compop_func op_5fc8_0_comp_nf;
extern compop_func op_5fd0_0_comp_nf;
extern compop_func op_5fd8_0_comp_nf;
extern compop_func op_5fe0_0_comp_nf;
extern compop_func op_5fe8_0_comp_nf;
extern compop_func op_5ff0_0_comp_nf;
extern compop_func op_5ff8_0_comp_nf;
extern compop_func op_5ff9_0_comp_nf;
extern compop_func op_6000_0_comp_nf;
extern compop_func op_6001_0_comp_nf;
extern compop_func op_60ff_0_comp_nf;
extern compop_func op_6100_0_comp_nf;
extern compop_func op_6101_0_comp_nf;
extern compop_func op_61ff_0_comp_nf;
extern compop_func op_6200_0_comp_nf;
extern compop_func op_6201_0_comp_nf;
extern compop_func op_62ff_0_comp_nf;
extern compop_func op_6300_0_comp_nf;
extern compop_func op_6301_0_comp_nf;
extern compop_func op_63ff_0_comp_nf;
extern compop_func op_6400_0_comp_nf;
extern compop_func op_6401_0_comp_nf;
extern compop_func op_64ff_0_comp_nf;
extern compop_func op_6500_0_comp_nf;
extern compop_func op_6501_0_comp_nf;
extern compop_func op_65ff_0_comp_nf;
extern compop_func op_6600_0_comp_nf;
extern compop_func op_6601_0_comp_nf;
extern compop_func op_66ff_0_comp_nf;
extern compop_func op_6700_0_comp_nf;
extern compop_func op_6701_0_comp_nf;
extern compop_func op_67ff_0_comp_nf;
extern compop_func op_6a00_0_comp_nf;
extern compop_func op_6a01_0_comp_nf;
extern compop_func op_6aff_0_comp_nf;
extern compop_func op_6b00_0_comp_nf;
extern compop_func op_6b01_0_comp_nf;
extern compop_func op_6bff_0_comp_nf;
extern compop_func op_6c00_0_comp_nf;
extern compop_func op_6c01_0_comp_nf;
extern compop_func op_6cff_0_comp_nf;
extern compop_func op_6d00_0_comp_nf;
extern compop_func op_6d01_0_comp_nf;
extern compop_func op_6dff_0_comp_nf;
extern compop_func op_6e00_0_comp_nf;
extern compop_func op_6e01_0_comp_nf;
extern compop_func op_6eff_0_comp_nf;
extern compop_func op_6f00_0_comp_nf;
extern compop_func op_6f01_0_comp_nf;
extern compop_func op_6fff_0_comp_nf;
extern compop_func op_7000_0_comp_nf;
extern compop_func op_8000_0_comp_nf;
extern compop_func op_8010_0_comp_nf;
extern compop_func op_8018_0_comp_nf;
extern compop_func op_8020_0_comp_nf;
extern compop_func op_8028_0_comp_nf;
extern compop_func op_8030_0_comp_nf;
extern compop_func op_8038_0_comp_nf;
extern compop_func op_8039_0_comp_nf;
extern compop_func op_803a_0_comp_nf;
extern compop_func op_803b_0_comp_nf;
extern compop_func op_803c_0_comp_nf;
extern compop_func op_8040_0_comp_nf;
extern compop_func op_8050_0_comp_nf;
extern compop_func op_8058_0_comp_nf;
extern compop_func op_8060_0_comp_nf;
extern compop_func op_8068_0_comp_nf;
extern compop_func op_8070_0_comp_nf;
extern compop_func op_8078_0_comp_nf;
extern compop_func op_8079_0_comp_nf;
extern compop_func op_807a_0_comp_nf;
extern compop_func op_807b_0_comp_nf;
extern compop_func op_807c_0_comp_nf;
extern compop_func op_8080_0_comp_nf;
extern compop_func op_8090_0_comp_nf;
extern compop_func op_8098_0_comp_nf;
extern compop_func op_80a0_0_comp_nf;
extern compop_func op_80a8_0_comp_nf;
extern compop_func op_80b0_0_comp_nf;
extern compop_func op_80b8_0_comp_nf;
extern compop_func op_80b9_0_comp_nf;
extern compop_func op_80ba_0_comp_nf;
extern compop_func op_80bb_0_comp_nf;
extern compop_func op_80bc_0_comp_nf;
extern compop_func op_8110_0_comp_nf;
extern compop_func op_8118_0_comp_nf;
extern compop_func op_8120_0_comp_nf;
extern compop_func op_8128_0_comp_nf;
extern compop_func op_8130_0_comp_nf;
extern compop_func op_8138_0_comp_nf;
extern compop_func op_8139_0_comp_nf;
extern compop_func op_8150_0_comp_nf;
extern compop_func op_8158_0_comp_nf;
extern compop_func op_8160_0_comp_nf;
extern compop_func op_8168_0_comp_nf;
extern compop_func op_8170_0_comp_nf;
extern compop_func op_8178_0_comp_nf;
extern compop_func op_8179_0_comp_nf;
extern compop_func op_8190_0_comp_nf;
extern compop_func op_8198_0_comp_nf;
extern compop_func op_81a0_0_comp_nf;
extern compop_func op_81a8_0_comp_nf;
extern compop_func op_81b0_0_comp_nf;
extern compop_func op_81b8_0_comp_nf;
extern compop_func op_81b9_0_comp_nf;
extern compop_func op_9000_0_comp_nf;
extern compop_func op_9010_0_comp_nf;
extern compop_func op_9018_0_comp_nf;
extern compop_func op_9020_0_comp_nf;
extern compop_func op_9028_0_comp_nf;
extern compop_func op_9030_0_comp_nf;
extern compop_func op_9038_0_comp_nf;
extern compop_func op_9039_0_comp_nf;
extern compop_func op_903a_0_comp_nf;
extern compop_func op_903b_0_comp_nf;
extern compop_func op_903c_0_comp_nf;
extern compop_func op_9040_0_comp_nf;
extern compop_func op_9048_0_comp_nf;
extern compop_func op_9050_0_comp_nf;
extern compop_func op_9058_0_comp_nf;
extern compop_func op_9060_0_comp_nf;
extern compop_func op_9068_0_comp_nf;
extern compop_func op_9070_0_comp_nf;
extern compop_func op_9078_0_comp_nf;
extern compop_func op_9079_0_comp_nf;
extern compop_func op_907a_0_comp_nf;
extern compop_func op_907b_0_comp_nf;
extern compop_func op_907c_0_comp_nf;
extern compop_func op_9080_0_comp_nf;
extern compop_func op_9088_0_comp_nf;
extern compop_func op_9090_0_comp_nf;
extern compop_func op_9098_0_comp_nf;
extern compop_func op_90a0_0_comp_nf;
extern compop_func op_90a8_0_comp_nf;
extern compop_func op_90b0_0_comp_nf;
extern compop_func op_90b8_0_comp_nf;
extern compop_func op_90b9_0_comp_nf;
extern compop_func op_90ba_0_comp_nf;
extern compop_func op_90bb_0_comp_nf;
extern compop_func op_90bc_0_comp_nf;
extern compop_func op_90c0_0_comp_nf;
extern compop_func op_90c8_0_comp_nf;
extern compop_func op_90d0_0_comp_nf;
extern compop_func op_90d8_0_comp_nf;
extern compop_func op_90e0_0_comp_nf;
extern compop_func op_90e8_0_comp_nf;
extern compop_func op_90f0_0_comp_nf;
extern compop_func op_90f8_0_comp_nf;
extern compop_func op_90f9_0_comp_nf;
extern compop_func op_90fa_0_comp_nf;
extern compop_func op_90fb_0_comp_nf;
extern compop_func op_90fc_0_comp_nf;
extern compop_func op_9100_0_comp_nf;
extern compop_func op_9108_0_comp_nf;
extern compop_func op_9110_0_comp_nf;
extern compop_func op_9118_0_comp_nf;
extern compop_func op_9120_0_comp_nf;
extern compop_func op_9128_0_comp_nf;
extern compop_func op_9130_0_comp_nf;
extern compop_func op_9138_0_comp_nf;
extern compop_func op_9139_0_comp_nf;
extern compop_func op_9140_0_comp_nf;
extern compop_func op_9148_0_comp_nf;
extern compop_func op_9150_0_comp_nf;
extern compop_func op_9158_0_comp_nf;
extern compop_func op_9160_0_comp_nf;
extern compop_func op_9168_0_comp_nf;
extern compop_func op_9170_0_comp_nf;
extern compop_func op_9178_0_comp_nf;
extern compop_func op_9179_0_comp_nf;
extern compop_func op_9180_0_comp_nf;
extern compop_func op_9188_0_comp_nf;
extern compop_func op_9190_0_comp_nf;
extern compop_func op_9198_0_comp_nf;
extern compop_func op_91a0_0_comp_nf;
extern compop_func op_91a8_0_comp_nf;
extern compop_func op_91b0_0_comp_nf;
extern compop_func op_91b8_0_comp_nf;
extern compop_func op_91b9_0_comp_nf;
extern compop_func op_91c0_0_comp_nf;
extern compop_func op_91c8_0_comp_nf;
extern compop_func op_91d0_0_comp_nf;
extern compop_func op_91d8_0_comp_nf;
extern compop_func op_91e0_0_comp_nf;
extern compop_func op_91e8_0_comp_nf;
extern compop_func op_91f0_0_comp_nf;
extern compop_func op_91f8_0_comp_nf;
extern compop_func op_91f9_0_comp_nf;
extern compop_func op_91fa_0_comp_nf;
extern compop_func op_91fb_0_comp_nf;
extern compop_func op_91fc_0_comp_nf;
extern compop_func op_b000_0_comp_nf;
extern compop_func op_b010_0_comp_nf;
extern compop_func op_b018_0_comp_nf;
extern compop_func op_b020_0_comp_nf;
extern compop_func op_b028_0_comp_nf;
extern compop_func op_b030_0_comp_nf;
extern compop_func op_b038_0_comp_nf;
extern compop_func op_b039_0_comp_nf;
extern compop_func op_b03a_0_comp_nf;
extern compop_func op_b03b_0_comp_nf;
extern compop_func op_b03c_0_comp_nf;
extern compop_func op_b040_0_comp_nf;
extern compop_func op_b048_0_comp_nf;
extern compop_func op_b050_0_comp_nf;
extern compop_func op_b058_0_comp_nf;
extern compop_func op_b060_0_comp_nf;
extern compop_func op_b068_0_comp_nf;
extern compop_func op_b070_0_comp_nf;
extern compop_func op_b078_0_comp_nf;
extern compop_func op_b079_0_comp_nf;
extern compop_func op_b07a_0_comp_nf;
extern compop_func op_b07b_0_comp_nf;
extern compop_func op_b07c_0_comp_nf;
extern compop_func op_b080_0_comp_nf;
extern compop_func op_b088_0_comp_nf;
extern compop_func op_b090_0_comp_nf;
extern compop_func op_b098_0_comp_nf;
extern compop_func op_b0a0_0_comp_nf;
extern compop_func op_b0a8_0_comp_nf;
extern compop_func op_b0b0_0_comp_nf;
extern compop_func op_b0b8_0_comp_nf;
extern compop_func op_b0b9_0_comp_nf;
extern compop_func op_b0ba_0_comp_nf;
extern compop_func op_b0bb_0_comp_nf;
extern compop_func op_b0bc_0_comp_nf;
extern compop_func op_b0c0_0_comp_nf;
extern compop_func op_b0c8_0_comp_nf;
extern compop_func op_b0d0_0_comp_nf;
extern compop_func op_b0d8_0_comp_nf;
extern compop_func op_b0e0_0_comp_nf;
extern compop_func op_b0e8_0_comp_nf;
extern compop_func op_b0f0_0_comp_nf;
extern compop_func op_b0f8_0_comp_nf;
extern compop_func op_b0f9_0_comp_nf;
extern compop_func op_b0fa_0_comp_nf;
extern compop_func op_b0fb_0_comp_nf;
extern compop_func op_b0fc_0_comp_nf;
extern compop_func op_b100_0_comp_nf;
extern compop_func op_b108_0_comp_nf;
extern compop_func op_b110_0_comp_nf;
extern compop_func op_b118_0_comp_nf;
extern compop_func op_b120_0_comp_nf;
extern compop_func op_b128_0_comp_nf;
extern compop_func op_b130_0_comp_nf;
extern compop_func op_b138_0_comp_nf;
extern compop_func op_b139_0_comp_nf;
extern compop_func op_b140_0_comp_nf;
extern compop_func op_b148_0_comp_nf;
extern compop_func op_b150_0_comp_nf;
extern compop_func op_b158_0_comp_nf;
extern compop_func op_b160_0_comp_nf;
extern compop_func op_b168_0_comp_nf;
extern compop_func op_b170_0_comp_nf;
extern compop_func op_b178_0_comp_nf;
extern compop_func op_b179_0_comp_nf;
extern compop_func op_b180_0_comp_nf;
extern compop_func op_b188_0_comp_nf;
extern compop_func op_b190_0_comp_nf;
extern compop_func op_b198_0_comp_nf;
extern compop_func op_b1a0_0_comp_nf;
extern compop_func op_b1a8_0_comp_nf;
extern compop_func op_b1b0_0_comp_nf;
extern compop_func op_b1b8_0_comp_nf;
extern compop_func op_b1b9_0_comp_nf;
extern compop_func op_b1c0_0_comp_nf;
extern compop_func op_b1c8_0_comp_nf;
extern compop_func op_b1d0_0_comp_nf;
extern compop_func op_b1d8_0_comp_nf;
extern compop_func op_b1e0_0_comp_nf;
extern compop_func op_b1e8_0_comp_nf;
extern compop_func op_b1f0_0_comp_nf;
extern compop_func op_b1f8_0_comp_nf;
extern compop_func op_b1f9_0_comp_nf;
extern compop_func op_b1fa_0_comp_nf;
extern compop_func op_b1fb_0_comp_nf;
extern compop_func op_b1fc_0_comp_nf;
extern compop_func op_c000_0_comp_nf;
extern compop_func op_c010_0_comp_nf;
extern compop_func op_c018_0_comp_nf;
extern compop_func op_c020_0_comp_nf;
extern compop_func op_c028_0_comp_nf;
extern compop_func op_c030_0_comp_nf;
extern compop_func op_c038_0_comp_nf;
extern compop_func op_c039_0_comp_nf;
extern compop_func op_c03a_0_comp_nf;
extern compop_func op_c03b_0_comp_nf;
extern compop_func op_c03c_0_comp_nf;
extern compop_func op_c040_0_comp_nf;
extern compop_func op_c050_0_comp_nf;
extern compop_func op_c058_0_comp_nf;
extern compop_func op_c060_0_comp_nf;
extern compop_func op_c068_0_comp_nf;
extern compop_func op_c070_0_comp_nf;
extern compop_func op_c078_0_comp_nf;
extern compop_func op_c079_0_comp_nf;
extern compop_func op_c07a_0_comp_nf;
extern compop_func op_c07b_0_comp_nf;
extern compop_func op_c07c_0_comp_nf;
extern compop_func op_c080_0_comp_nf;
extern compop_func op_c090_0_comp_nf;
extern compop_func op_c098_0_comp_nf;
extern compop_func op_c0a0_0_comp_nf;
extern compop_func op_c0a8_0_comp_nf;
extern compop_func op_c0b0_0_comp_nf;
extern compop_func op_c0b8_0_comp_nf;
extern compop_func op_c0b9_0_comp_nf;
extern compop_func op_c0ba_0_comp_nf;
extern compop_func op_c0bb_0_comp_nf;
extern compop_func op_c0bc_0_comp_nf;
extern compop_func op_c0c0_0_comp_nf;
extern compop_func op_c0d0_0_comp_nf;
extern compop_func op_c0d8_0_comp_nf;
extern compop_func op_c0e0_0_comp_nf;
extern compop_func op_c0e8_0_comp_nf;
extern compop_func op_c0f0_0_comp_nf;
extern compop_func op_c0f8_0_comp_nf;
extern compop_func op_c0f9_0_comp_nf;
extern compop_func op_c0fa_0_comp_nf;
extern compop_func op_c0fb_0_comp_nf;
extern compop_func op_c0fc_0_comp_nf;
extern compop_func op_c110_0_comp_nf;
extern compop_func op_c118_0_comp_nf;
extern compop_func op_c120_0_comp_nf;
extern compop_func op_c128_0_comp_nf;
extern compop_func op_c130_0_comp_nf;
extern compop_func op_c138_0_comp_nf;
extern compop_func op_c139_0_comp_nf;
extern compop_func op_c140_0_comp_nf;
extern compop_func op_c148_0_comp_nf;
extern compop_func op_c150_0_comp_nf;
extern compop_func op_c158_0_comp_nf;
extern compop_func op_c160_0_comp_nf;
extern compop_func op_c168_0_comp_nf;
extern compop_func op_c170_0_comp_nf;
extern compop_func op_c178_0_comp_nf;
extern compop_func op_c179_0_comp_nf;
extern compop_func op_c188_0_comp_nf;
extern compop_func op_c190_0_comp_nf;
extern compop_func op_c198_0_comp_nf;
extern compop_func op_c1a0_0_comp_nf;
extern compop_func op_c1a8_0_comp_nf;
extern compop_func op_c1b0_0_comp_nf;
extern compop_func op_c1b8_0_comp_nf;
extern compop_func op_c1b9_0_comp_nf;
extern compop_func op_c1c0_0_comp_nf;
extern compop_func op_c1d0_0_comp_nf;
extern compop_func op_c1d8_0_comp_nf;
extern compop_func op_c1e0_0_comp_nf;
extern compop_func op_c1e8_0_comp_nf;
extern compop_func op_c1f0_0_comp_nf;
extern compop_func op_c1f8_0_comp_nf;
extern compop_func op_c1f9_0_comp_nf;
extern compop_func op_c1fa_0_comp_nf;
extern compop_func op_c1fb_0_comp_nf;
extern compop_func op_c1fc_0_comp_nf;
extern compop_func op_d000_0_comp_nf;
extern compop_func op_d010_0_comp_nf;
extern compop_func op_d018_0_comp_nf;
extern compop_func op_d020_0_comp_nf;
extern compop_func op_d028_0_comp_nf;
extern compop_func op_d030_0_comp_nf;
extern compop_func op_d038_0_comp_nf;
extern compop_func op_d039_0_comp_nf;
extern compop_func op_d03a_0_comp_nf;
extern compop_func op_d03b_0_comp_nf;
extern compop_func op_d03c_0_comp_nf;
extern compop_func op_d040_0_comp_nf;
extern compop_func op_d048_0_comp_nf;
extern compop_func op_d050_0_comp_nf;
extern compop_func op_d058_0_comp_nf;
extern compop_func op_d060_0_comp_nf;
extern compop_func op_d068_0_comp_nf;
extern compop_func op_d070_0_comp_nf;
extern compop_func op_d078_0_comp_nf;
extern compop_func op_d079_0_comp_nf;
extern compop_func op_d07a_0_comp_nf;
extern compop_func op_d07b_0_comp_nf;
extern compop_func op_d07c_0_comp_nf;
extern compop_func op_d080_0_comp_nf;
extern compop_func op_d088_0_comp_nf;
extern compop_func op_d090_0_comp_nf;
extern compop_func op_d098_0_comp_nf;
extern compop_func op_d0a0_0_comp_nf;
extern compop_func op_d0a8_0_comp_nf;
extern compop_func op_d0b0_0_comp_nf;
extern compop_func op_d0b8_0_comp_nf;
extern compop_func op_d0b9_0_comp_nf;
extern compop_func op_d0ba_0_comp_nf;
extern compop_func op_d0bb_0_comp_nf;
extern compop_func op_d0bc_0_comp_nf;
extern compop_func op_d0c0_0_comp_nf;
extern compop_func op_d0c8_0_comp_nf;
extern compop_func op_d0d0_0_comp_nf;
extern compop_func op_d0d8_0_comp_nf;
extern compop_func op_d0e0_0_comp_nf;
extern compop_func op_d0e8_0_comp_nf;
extern compop_func op_d0f0_0_comp_nf;
extern compop_func op_d0f8_0_comp_nf;
extern compop_func op_d0f9_0_comp_nf;
extern compop_func op_d0fa_0_comp_nf;
extern compop_func op_d0fb_0_comp_nf;
extern compop_func op_d0fc_0_comp_nf;
extern compop_func op_d100_0_comp_nf;
extern compop_func op_d108_0_comp_nf;
extern compop_func op_d110_0_comp_nf;
extern compop_func op_d118_0_comp_nf;
extern compop_func op_d120_0_comp_nf;
extern compop_func op_d128_0_comp_nf;
extern compop_func op_d130_0_comp_nf;
extern compop_func op_d138_0_comp_nf;
extern compop_func op_d139_0_comp_nf;
extern compop_func op_d140_0_comp_nf;
extern compop_func op_d148_0_comp_nf;
extern compop_func op_d150_0_comp_nf;
extern compop_func op_d158_0_comp_nf;
extern compop_func op_d160_0_comp_nf;
extern compop_func op_d168_0_comp_nf;
extern compop_func op_d170_0_comp_nf;
extern compop_func op_d178_0_comp_nf;
extern compop_func op_d179_0_comp_nf;
extern compop_func op_d180_0_comp_nf;
extern compop_func op_d188_0_comp_nf;
extern compop_func op_d190_0_comp_nf;
extern compop_func op_d198_0_comp_nf;
extern compop_func op_d1a0_0_comp_nf;
extern compop_func op_d1a8_0_comp_nf;
extern compop_func op_d1b0_0_comp_nf;
extern compop_func op_d1b8_0_comp_nf;
extern compop_func op_d1b9_0_comp_nf;
extern compop_func op_d1c0_0_comp_nf;
extern compop_func op_d1c8_0_comp_nf;
extern compop_func op_d1d0_0_comp_nf;
extern compop_func op_d1d8_0_comp_nf;
extern compop_func op_d1e0_0_comp_nf;
extern compop_func op_d1e8_0_comp_nf;
extern compop_func op_d1f0_0_comp_nf;
extern compop_func op_d1f8_0_comp_nf;
extern compop_func op_d1f9_0_comp_nf;
extern compop_func op_d1fa_0_comp_nf;
extern compop_func op_d1fb_0_comp_nf;
extern compop_func op_d1fc_0_comp_nf;
extern compop_func op_e000_0_comp_nf;
extern compop_func op_e008_0_comp_nf;
extern compop_func op_e018_0_comp_nf;
extern compop_func op_e020_0_comp_nf;
extern compop_func op_e028_0_comp_nf;
extern compop_func op_e038_0_comp_nf;
extern compop_func op_e040_0_comp_nf;
extern compop_func op_e048_0_comp_nf;
extern compop_func op_e058_0_comp_nf;
extern compop_func op_e060_0_comp_nf;
extern compop_func op_e068_0_comp_nf;
extern compop_func op_e078_0_comp_nf;
extern compop_func op_e080_0_comp_nf;
extern compop_func op_e088_0_comp_nf;
extern compop_func op_e098_0_comp_nf;
extern compop_func op_e0a0_0_comp_nf;
extern compop_func op_e0a8_0_comp_nf;
extern compop_func op_e0b8_0_comp_nf;
extern compop_func op_e0d0_0_comp_nf;
extern compop_func op_e0d8_0_comp_nf;
extern compop_func op_e0e0_0_comp_nf;
extern compop_func op_e0e8_0_comp_nf;
extern compop_func op_e0f0_0_comp_nf;
extern compop_func op_e0f8_0_comp_nf;
extern compop_func op_e0f9_0_comp_nf;
extern compop_func op_e100_0_comp_nf;
extern compop_func op_e108_0_comp_nf;
extern compop_func op_e118_0_comp_nf;
extern compop_func op_e120_0_comp_nf;
extern compop_func op_e128_0_comp_nf;
extern compop_func op_e138_0_comp_nf;
extern compop_func op_e140_0_comp_nf;
extern compop_func op_e148_0_comp_nf;
extern compop_func op_e158_0_comp_nf;
extern compop_func op_e160_0_comp_nf;
extern compop_func op_e168_0_comp_nf;
extern compop_func op_e178_0_comp_nf;
extern compop_func op_e180_0_comp_nf;
extern compop_func op_e188_0_comp_nf;
extern compop_func op_e198_0_comp_nf;
extern compop_func op_e1a0_0_comp_nf;
extern compop_func op_e1a8_0_comp_nf;
extern compop_func op_e1b8_0_comp_nf;
extern compop_func op_e1d0_0_comp_nf;
extern compop_func op_e1d8_0_comp_nf;
extern compop_func op_e1e0_0_comp_nf;
extern compop_func op_e1e8_0_comp_nf;
extern compop_func op_e1f0_0_comp_nf;
extern compop_func op_e1f8_0_comp_nf;
extern compop_func op_e1f9_0_comp_nf;
extern compop_func op_e2d0_0_comp_nf;
extern compop_func op_e2d8_0_comp_nf;
extern compop_func op_e2e0_0_comp_nf;
extern compop_func op_e2e8_0_comp_nf;
extern compop_func op_e2f0_0_comp_nf;
extern compop_func op_e2f8_0_comp_nf;
extern compop_func op_e2f9_0_comp_nf;
extern compop_func op_e3d0_0_comp_nf;
extern compop_func op_e3d8_0_comp_nf;
extern compop_func op_e3e0_0_comp_nf;
extern compop_func op_e3e8_0_comp_nf;
extern compop_func op_e3f0_0_comp_nf;
extern compop_func op_e3f8_0_comp_nf;
extern compop_func op_e3f9_0_comp_nf;
extern compop_func op_e6d0_0_comp_nf;
extern compop_func op_e6d8_0_comp_nf;
extern compop_func op_e6e0_0_comp_nf;
extern compop_func op_e6e8_0_comp_nf;
extern compop_func op_e6f0_0_comp_nf;
extern compop_func op_e6f8_0_comp_nf;
extern compop_func op_e6f9_0_comp_nf;
extern compop_func op_e7d0_0_comp_nf;
extern compop_func op_e7d8_0_comp_nf;
extern compop_func op_e7e0_0_comp_nf;
extern compop_func op_e7e8_0_comp_nf;
extern compop_func op_e7f0_0_comp_nf;
extern compop_func op_e7f8_0_comp_nf;
extern compop_func op_e7f9_0_comp_nf;
extern compop_func op_f600_0_comp_nf;
extern compop_func op_f608_0_comp_nf;
extern compop_func op_f610_0_comp_nf;
extern compop_func op_f618_0_comp_nf;
extern compop_func op_f620_0_comp_nf;
